@@ -2,7 +2,7 @@
 // Licensed under the GNU LGPL Version 2.1.
 //
 // First added:  2009-11-11
-// Last changed: 2009-11-11
+// Last changed: 2010-04-29
 //
 // This program demonstrates the use of the TimeSeries
 // class for storing a series of meshes and vectors.
@@ -17,7 +17,8 @@ int main()
   TimeSeries series("primal");
 
   // Create a mesh and a vector
-  UnitSquare mesh(2, 2);
+  UnitSquare unitsquare_mesh(2, 2);
+  Mesh mesh(unitsquare_mesh);
   Vector x;
 
   // Add a bunch of meshes and vectors to the series
@@ -25,13 +26,18 @@ int main()
   while (t < 1.0)
   {
     // Refine mesh and resize vector
-    mesh.refine();
-    x.resize(mesh.num_vertices());
+    Mesh new_mesh = refine(mesh);
+    x.resize(new_mesh.num_vertices());
+
+    // Set some vector values
+    for (dolfin::uint i = 0; i < x.size(); i++)
+      x.setitem(i, (t + 1.0)*static_cast<double>(i));
 
     // Append to series
-    series.store(mesh, t);
+    series.store(new_mesh, t);
     series.store(x, t);
 
+    mesh = new_mesh;
     t += 0.2;
   }
 
