@@ -8,12 +8,12 @@ __license__  = "GNU LGPL Version 2.1"
 from dolfin import *
 
 # Create mesh of unit square
-mesh = UnitSquare(5, 5)
-plot(mesh, interactive=True)
+mesh = UnitSquare(32, 32)
+plot(mesh)
 
 # Uniform refinement
-mesh.refine()
-plot(mesh, interactive=True)
+mesh = refine(mesh)
+plot(mesh)
 
 # Refine mesh close to x = (0.5, 0.5)
 p = Point(0.5, 0.5)
@@ -28,7 +28,9 @@ for i in range(5):
             cell_markers[c] = False
 
     # Refine mesh
-    mesh.refine(cell_markers)
+    mesh = refine(mesh, cell_markers)
 
     # Plot mesh
-    plot(mesh, interactive=True)
+    plot(mesh)
+
+interactive()
