@@ -9,11 +9,11 @@ on the unit square with source f given by
 and boundary conditions given by
 
     u(x, y) = 0        for x = 0 or x = 1
-du/dn(x, y) = sin(5*x) for y = 0 or y = 1
+du/dn(x, y) = -sin(5*x) for y = 0 or y = 1
 """
 
 __author__ = "Anders Logg (logg@simula.no)"
-__date__ = "2007-08-16 -- 2009-11-24"
+__date__ = "2007-08-16 -- 2010-03-05"
 __copyright__ = "Copyright (C) 2007-2009 Anders Logg"
 __license__  = "GNU LGPL Version 2.1"
 
@@ -35,9 +35,9 @@ bc = DirichletBC(V, u0, boundary)
 v = TestFunction(V)
 u = TrialFunction(V)
 f = Expression("10*exp(-(pow(x[0] - 0.5, 2) + pow(x[1] - 0.5, 2)) / 0.02)")
-g = Expression("sin(5*x[0])")
+g = Expression("-sin(5*x[0])")
 a = inner(grad(v), grad(u))*dx
-L = v*f*dx - v*g*ds
+L = v*f*dx + v*g*ds
 
 # Compute solution
 problem = VariationalProblem(a, L, bc)
