@@ -4,6 +4,7 @@
 // First added:  2008-08-11
 // Last changed: 2008-09-13
 
+#include <dolfin/common/Array.h>
 #include <dolfin/fem/Assembler.h>
 #include <dolfin/log/log.h>
 #include <dolfin/la/Matrix.h>
@@ -59,11 +60,11 @@ void HarmonicSmoothing::move(Mesh& mesh, Mesh& new_boundary)
 
   // Modify matrix (insert 1 on diagonal)
   A.ident(num_dofs, dofs);
-  A.apply();
+  A.apply("insert");
 
   // Solve system for each dimension
   double* values = new double[num_dofs];
-  double* new_coordinates = new double[d*N];
+  Array<double> new_coordinates(d*N);
   Vector x;
   for (uint dim = 0; dim < d; dim++)
   {
@@ -73,13 +74,14 @@ void HarmonicSmoothing::move(Mesh& mesh, Mesh& new_boundary)
 
     // Modify right-hand side
     b.set(values, num_dofs, dofs);
-    b.apply();
+    b.apply("insert");
 
     // Solve system
     solve(A, x, b, "gmres", "amg_hypre");
 
     // Get new coordinates
-    x.get_local(new_coordinates + dim*N);
+    Array<double> _new_coordinates(N, new_coordinates.data().get() + dim*N);
+    x.get_local(_new_coordinates);
   }
 
   // Modify mesh coordinates
@@ -92,6 +94,5 @@ void HarmonicSmoothing::move(Mesh& mesh, Mesh& new_boundary)
   delete V;
   delete form;
   delete [] values;
-  delete [] new_coordinates;
 }
 //-----------------------------------------------------------------------------
