@@ -6,7 +6,7 @@
 // Modified by Kent-Andre Mardal, 2008
 //
 // First added:  2007-01-17
-// Last changed: 2010-02-17
+// Last changed: 2010-02-27
 
 #include <dolfin/log/dolfin_log.h>
 #include <dolfin/common/Timer.h>
@@ -15,12 +15,11 @@
 #include <dolfin/mesh/Cell.h>
 #include <dolfin/mesh/Facet.h>
 #include <dolfin/mesh/MeshData.h>
-#include <dolfin/mesh/BoundaryMesh.h>
 #include <dolfin/mesh/MeshFunction.h>
 #include <dolfin/mesh/SubDomain.h>
 #include <dolfin/function/GenericFunction.h>
 #include <dolfin/function/FunctionSpace.h>
-#include "DofMap.h"
+#include "GenericDofMap.h"
 #include "Form.h"
 #include "UFC.h"
 #include "AssemblerTools.h"
@@ -112,7 +111,7 @@ void Assembler::assemble(GenericTensor& A,
   assemble_interior_facets(A, a, ufc, interior_facet_domains, 0);
 
   // Finalise assembly of global tensor
-  A.apply();
+  A.apply("add");
 }
 //-----------------------------------------------------------------------------
 void Assembler::assemble_cells(GenericTensor& A,
@@ -146,7 +145,7 @@ void Assembler::assemble_cells(GenericTensor& A,
         continue;
     }
 
-    // Skip integral is zero
+    // Skip integral if zero
     if (!integral) continue;
 
     // Update to current cell
@@ -190,43 +189,45 @@ void Assembler::assemble_exterior_facets(GenericTensor& A,
   // Exterior facet integral
   ufc::exterior_facet_integral* integral = ufc.exterior_facet_integrals[0];
 
-  // Create boundary mesh
-  BoundaryMesh boundary(mesh);
+  // Compute facets and facet - cell connectivity if not already computed
+  const uint D = mesh.topology().dim();
+  mesh.init(D - 1);
+  mesh.init(D - 1, D);
+  assert(mesh.ordered());
 
-  // Skip assembly if boundary is empty (may happen when running in parallel)
-  if (boundary.num_cells() == 0)
-    return;
-
-  // Get mapping from facets (boundary cells) to mesh cells
-  MeshFunction<uint>* cell_map = boundary.data().mesh_function("cell map");
-  assert(cell_map);
+  // Extract exterior (non shared) facets markers
+  MeshFunction<uint>* exterior_facets = mesh.data().mesh_function("exterior facets");
 
   // Assemble over exterior facets (the cells of the boundary)
-  Progress p(AssemblerTools::progress_message(A.rank(), "exterior facets"), boundary.num_cells());
-  for (CellIterator boundary_cell(boundary); !boundary_cell.end(); ++boundary_cell)
+  Progress p(AssemblerTools::progress_message(A.rank(), "exterior facets"), mesh.num_facets());
+  for (FacetIterator facet(mesh); !facet.end(); ++facet)
   {
-    // Get mesh facet corresponding to boundary cell
-    Facet mesh_facet(mesh, (*cell_map)[*boundary_cell]);
+    // Only consider exterior facets
+    if (facet->num_entities(D) == 2 || (exterior_facets && !(*exterior_facets)[*facet]))
+    {
+      p++;
+      continue;
+    }
 
     // Get integral for sub domain (if any)
     if (domains && domains->size() > 0)
     {
-      const uint domain = (*domains)[mesh_facet];
+      const uint domain = (*domains)[*facet];
       if (domain < ufc.form.num_exterior_facet_integrals())
         integral = ufc.exterior_facet_integrals[domain];
       else
         continue;
     }
 
-    // Skip integral is zero
+    // Skip integral if zero
     if (!integral) continue;
 
     // Get mesh cell to which mesh facet belongs (pick first, there is only one)
-    assert(mesh_facet.num_entities(mesh.topology().dim()) == 1);
-    Cell mesh_cell(mesh, mesh_facet.entities(mesh.topology().dim())[0]);
+    assert(facet->num_entities(mesh.topology().dim()) == 1);
+    Cell mesh_cell(mesh, facet->entities(mesh.topology().dim())[0]);
 
     // Get local index of facet with respect to the cell
-    const uint local_facet = mesh_cell.index(mesh_facet);
+    const uint local_facet = mesh_cell.index(*facet);
 
     // Update to current cell
     ufc.update(mesh_cell, local_facet);
@@ -282,7 +283,7 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
   Progress p(AssemblerTools::progress_message(A.rank(), "interior facets"), mesh.num_facets());
   for (FacetIterator facet(mesh); !facet.end(); ++facet)
   {
-    // Check if we have an exterior facet or a facet belonging to another process
+    // Only consider interior facets
     if (!facet->interior())
     {
       p++;
@@ -299,7 +300,7 @@ void Assembler::assemble_interior_facets(GenericTensor& A,
         continue;
     }
 
-    // Skip integral is zero
+    // Skip integral if zero
     if (!integral) continue;
 
     // Get cells incident with facet
