@@ -6,13 +6,14 @@
 // Modified by Johan Hake, 2009
 //
 // First added:  2007-04-10
-// Last changed: 2009-12-03
+// Last changed: 2010-05-14
 
 #include <boost/scoped_ptr.hpp>
 #include <boost/assign/list_of.hpp>
 
-#include <dolfin/common/NoDeleter.h>
 #include <dolfin/common/constants.h>
+#include <dolfin/common/Array.h>
+#include <dolfin/common/NoDeleter.h>
 #include <dolfin/function/GenericFunction.h>
 #include <dolfin/function/FunctionSpace.h>
 #include <dolfin/log/log.h>
@@ -27,7 +28,7 @@
 #include <dolfin/la/GenericMatrix.h>
 #include <dolfin/la/GenericVector.h>
 #include <dolfin/la/LinearAlgebraFactory.h>
-#include "DofMap.h"
+#include "GenericDofMap.h"
 #include "FiniteElement.h"
 #include "UFCMesh.h"
 #include "UFCCell.h"
@@ -47,6 +48,7 @@ DirichletBC::DirichletBC(const FunctionSpace& V,
     method(method), user_sub_domain(reference_to_no_delete_pointer(sub_domain))
 {
   check();
+  parameters = default_parameters();
   init_from_sub_domain(user_sub_domain);
 }
 //-----------------------------------------------------------------------------
@@ -59,6 +61,7 @@ DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
     method(method), user_sub_domain(sub_domain)
 {
   check();
+  parameters = default_parameters();
   init_from_sub_domain(user_sub_domain);
 }
 //-----------------------------------------------------------------------------
@@ -72,6 +75,7 @@ DirichletBC::DirichletBC(const FunctionSpace& V,
     method(method), user_sub_domain(static_cast<SubDomain*>(0))
 {
   check();
+  parameters = default_parameters();
   init_from_mesh_function(sub_domains, sub_domain);
 }
 //-----------------------------------------------------------------------------
@@ -85,6 +89,7 @@ DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
     method(method), user_sub_domain(static_cast<SubDomain*>(0))
 {
   check();
+  parameters = default_parameters();
   init_from_mesh_function(sub_domains, sub_domain);
 }
 //-----------------------------------------------------------------------------
@@ -97,6 +102,7 @@ DirichletBC::DirichletBC(const FunctionSpace& V,
     method(method), user_sub_domain(static_cast<SubDomain*>(0))
 {
   check();
+  parameters = default_parameters();
   init_from_mesh(sub_domain);
 }
 //-----------------------------------------------------------------------------
@@ -109,6 +115,7 @@ DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
     method(method), user_sub_domain(static_cast<SubDomain*>(0))
 {
   check();
+  parameters = default_parameters();
   init_from_mesh(sub_domain);
 }
 //-----------------------------------------------------------------------------
@@ -122,6 +129,7 @@ DirichletBC::DirichletBC(const FunctionSpace& V,
     facets(markers)
 {
   check();
+  parameters = default_parameters();
 }
 //-----------------------------------------------------------------------------
 DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
@@ -134,11 +142,15 @@ DirichletBC::DirichletBC(boost::shared_ptr<const FunctionSpace> V,
     facets(markers)
 {
   check();
+  parameters = default_parameters();
 }
 //-----------------------------------------------------------------------------
 DirichletBC::DirichletBC(const DirichletBC& bc)
   : BoundaryCondition(bc._function_space)
 {
+  // Set default parameters
+  parameters = default_parameters();
+
   *this = bc;
 }
 //-----------------------------------------------------------------------------
@@ -207,7 +219,7 @@ void DirichletBC::zero(GenericMatrix& A) const
   A.zero(boundary_values.size(), dofs);
 
   // Finalise changes to A
-  A.apply();
+  A.apply("insert");
 
   // Clear temporary arrays
   delete [] dofs;
@@ -343,29 +355,37 @@ void DirichletBC::apply(GenericMatrix* A,
       values[i] = x_values[i] - values[i];
   }
 
-  info("Applying boundary conditions to linear system.");
+  info(PROGRESS, "Applying boundary conditions to linear system.");
 
   // Modify RHS vector (b[i] = value) and apply changes
   if (b)
   {
     b->set(&values[0], size, &dofs[0]);
-    b->apply();
+    b->apply("insert");
   }
 
   // Modify linear system (A_ii = 1) and apply changes
   if (A)
   {
-    A->ident(size, &dofs[0]);
-    A->apply();
+    const bool use_ident = parameters["use_ident"];
+    if (use_ident)
+    {
+      A->ident(size, &dofs[0]);
+    }
+    else
+    {
+      for (uint i = 0; i < size; i++)
+      {
+        std::pair<uint, uint> ij(dofs[i], dofs[i]);
+        A->setitem(ij, 1.0);
+      }
+    }
+    A->apply("insert");
   }
 }
 //-----------------------------------------------------------------------------
 void DirichletBC::check() const
 {
-  // Check that function is in function space
-  //if (!g->in(*_function_space))
-  //  error("Unable to create boundary condition, boundary value function is not in trial space.");
-
   // Check that value shape of boundary value
   check_equal(g->value_rank(), _function_space->element().value_rank(),
               "create boundary condition", "value rank");
@@ -516,7 +536,7 @@ void DirichletBC::compute_bc_topological(std::map<uint, double>& boundary_values
 
   // Get mesh and dofmap
   const Mesh& mesh = _function_space->mesh();
-  const DofMap& dofmap = _function_space->dofmap();
+  const GenericDofMap& dofmap = _function_space->dofmap();
 
   // Iterate over facets
   Progress p("Computing Dirichlet boundary values, topological search", facets.size());
@@ -573,10 +593,10 @@ void DirichletBC::compute_bc_geometric(std::map<uint, double>& boundary_values,
 
   // Get mesh and dofmap
   const Mesh& mesh = _function_space->mesh();
-  const DofMap& dofmap = _function_space->dofmap();
+  const GenericDofMap& dofmap = _function_space->dofmap();
 
   // Initialize facets, needed for geometric search
-  info("Computing facets, needed for geometric application of boundary conditions.");
+  info(TRACE, "Computing facets, needed for geometric application of boundary conditions.");
   mesh.init(mesh.topology().dim() - 1);
 
   // Iterate over facets
@@ -639,7 +659,7 @@ void DirichletBC::compute_bc_pointwise(std::map<uint, double>& boundary_values,
 
   // Get mesh and dofmap
   const Mesh& mesh = _function_space->mesh();
-  const DofMap& dofmap = _function_space->dofmap();
+  const GenericDofMap& dofmap = _function_space->dofmap();
 
   // Iterate over cells
   Progress p("Computing Dirichlet boundary values, pointwise search", mesh.num_cells());
@@ -657,7 +677,7 @@ void DirichletBC::compute_bc_pointwise(std::map<uint, double>& boundary_values,
     for (uint i = 0; i < dofmap.local_dimension(ufc_cell); ++i)
     {
       // Check if the coordinates are part of the sub domain
-      if ( !user_sub_domain->inside(data.coordinates[i], false) )
+      if (!user_sub_domain->inside(data.array_coordinates[i], false))
         continue;
 
       if (!interpolated)
