@@ -2,7 +2,7 @@
 // Licensed under the GNU LGPL Version 2.1.
 //
 // First added:  2008-12-26
-// Last changed: 2009-10-06
+// Last changed: 2010-05-03
 
 #include <dolfin/la/Matrix.h>
 #include <dolfin/la/Vector.h>
@@ -23,9 +23,7 @@ VariationalProblem::VariationalProblem(const Form& a,
                                        const Form& L,
                                        bool nonlinear)
   : a(a), L(L), cell_domains(0), exterior_facet_domains(0),
-    interior_facet_domains(0), nonlinear(nonlinear), jacobian_initialised(false), 
-    _newton_solver(0)
-
+    interior_facet_domains(0), nonlinear(nonlinear), jacobian_initialised(false)
 {
   // Set default parameter values
   parameters = default_parameters();
@@ -36,8 +34,7 @@ VariationalProblem::VariationalProblem(const Form& a,
                                        const BoundaryCondition& bc,
                                        bool nonlinear)
   : a(a), L(L), cell_domains(0), exterior_facet_domains(0),
-    interior_facet_domains(0), nonlinear(nonlinear), jacobian_initialised(false), 
-    _newton_solver(0)
+    interior_facet_domains(0), nonlinear(nonlinear), jacobian_initialised(false)
 {
   // Set default parameters
   parameters = default_parameters();
@@ -51,8 +48,7 @@ VariationalProblem::VariationalProblem(const Form& a,
                                        const std::vector<const BoundaryCondition*>& bcs,
                                        bool nonlinear)
   : a(a), L(L), cell_domains(0), exterior_facet_domains(0),
-    interior_facet_domains(0), nonlinear(nonlinear), jacobian_initialised(false),
-    _newton_solver(0)
+    interior_facet_domains(0), nonlinear(nonlinear), jacobian_initialised(false)
 {
   // Set default parameters
   parameters = default_parameters();
@@ -71,8 +67,8 @@ VariationalProblem::VariationalProblem(const Form& a,
                                        bool nonlinear)
   : a(a), L(L), cell_domains(cell_domains),
     exterior_facet_domains(exterior_facet_domains),
-    interior_facet_domains(interior_facet_domains), nonlinear(nonlinear), 
-    jacobian_initialised(false), _newton_solver(0)
+    interior_facet_domains(interior_facet_domains), nonlinear(nonlinear),
+    jacobian_initialised(false)
 {
   // Set default parameters
   parameters = default_parameters();
@@ -84,7 +80,7 @@ VariationalProblem::VariationalProblem(const Form& a,
 //-----------------------------------------------------------------------------
 VariationalProblem::~VariationalProblem()
 {
-  delete _newton_solver;
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
 void VariationalProblem::solve(Function& u)
@@ -98,9 +94,9 @@ void VariationalProblem::solve(Function& u)
 //-----------------------------------------------------------------------------
 void VariationalProblem::solve(Function& u0, Function& u1)
 {
-  // Create function 
+  // Create function
   Function u(a.function_space(0));
-  
+
   // Solve variational problem
   solve(u);
 
@@ -111,7 +107,7 @@ void VariationalProblem::solve(Function& u0, Function& u1)
 //-----------------------------------------------------------------------------
 void VariationalProblem::solve(Function& u0, Function& u1, Function& u2)
 {
-  // Create function 
+  // Create function
   Function u(a.function_space(0));
 
   // Solve variational problem
@@ -135,6 +131,11 @@ void VariationalProblem::F(GenericVector& b, const GenericVector& x)
   // Apply boundary conditions
   for (uint i = 0; i < bcs.size(); i++)
     bcs[i]->apply(b, x);
+
+  // Print vector
+  const bool print_rhs = parameters["print_rhs"];
+  if (print_rhs == true)
+    info(b, true);
 }
 //-----------------------------------------------------------------------------
 void VariationalProblem::J(GenericMatrix& A, const GenericVector& x)
@@ -143,19 +144,24 @@ void VariationalProblem::J(GenericMatrix& A, const GenericVector& x)
   if (!nonlinear)
     error("Attempt to solve linear variational problem with Newton solver.");
 
-  // Check if Jacobian matrix sparsity pattern should be reset 
+  // Check if Jacobian matrix sparsity pattern should be reset
   bool reset_sparsity = true;
-  if (parameters["reset_jacobian"] && jacobian_initialised) 
+  if (parameters["reset_jacobian"] && jacobian_initialised)
     reset_sparsity = false;
 
   // Assemble
-  assemble(A, a, cell_domains, exterior_facet_domains, interior_facet_domains, 
+  assemble(A, a, cell_domains, exterior_facet_domains, interior_facet_domains,
            reset_sparsity);
   jacobian_initialised = true;
 
   // Apply boundary conditions
   for (uint i = 0; i < bcs.size(); i++)
     bcs[i]->apply(A);
+
+  // Print matrix
+  const bool print_matrix = parameters["print_matrix"];
+  if (print_matrix == true)
+    info(A, true);
 }
 //-----------------------------------------------------------------------------
 void VariationalProblem::update(const GenericVector& x)
@@ -168,7 +174,7 @@ NewtonSolver& VariationalProblem::newton_solver()
   // Create Newton solver if missing
   if (!_newton_solver)
   {
-    _newton_solver = new NewtonSolver();
+    _newton_solver.reset(new NewtonSolver);
     _newton_solver->parameters.update(parameters("newton_solver"));
   }
 
@@ -180,8 +186,12 @@ void VariationalProblem::solve_linear(Function& u)
 {
   begin("Solving linear variational problem");
 
-  // Check if system is symmetric
+  // Get parameters
+  std::string solver_type = parameters["linear_solver"];
+  const std::string pc_type = parameters["preconditioner"];
   const bool symmetric = parameters["symmetric"];
+  const bool print_rhs    = parameters["print_rhs"];
+  const bool print_matrix = parameters["print_matrix"];
 
   // Create matrix and vector
   Matrix A;
@@ -214,31 +224,36 @@ void VariationalProblem::solve_linear(Function& u)
       bcs[i]->apply(A, b);
   }
 
-  // Solve linear system
-  const std::string solver_type = parameters["linear_solver"];
-  if (solver_type == "direct")
+  // Print vector/matrix
+  if (print_rhs == true)
+    info(b, true);
+  if (print_matrix == true)
+    info(A, true);
+
+  // Adjust solver type if necessary
+  if (solver_type == "iterative")
+  {
+    if (symmetric)
+      solver_type = "cg";
+    else
+      solver_type = "gmres";
+  }
+
+  //  Solve linear system
+  if (solver_type == "lu" || solver_type == "direct")
   {
     LUSolver solver;
     solver.parameters.update(parameters("lu_solver"));
     solver.solve(A, u.vector(), b);
-  }
-  else if (solver_type == "iterative")
-  {
-    if (symmetric)
-    {
-      KrylovSolver solver("cg");
-      solver.parameters.update(parameters("krylov_solver"));
-      solver.solve(A, u.vector(), b);
-    }
-    else
-    {
-      KrylovSolver solver("gmres");
-      solver.parameters.update(parameters("krylov_solver"));
-      solver.solve(A, u.vector(), b);
-    }
+    if (pc_type != "none")
+      warning("Using LU solver, ignoring preconditioner \"%s\".", pc_type.c_str());
   }
   else
-    error("Unknown solver type \"%s\".", solver_type.c_str());
+  {
+    KrylovSolver solver(solver_type, pc_type);
+    solver.parameters.update(parameters("krylov_solver"));
+    solver.solve(A, u.vector(), b);
+  }
 
   end();
 }
