@@ -2,12 +2,13 @@
 // Licensed under the GNU LGPL Version 2.1.
 //
 // First added:  2008-12-26
-// Last changed: 2009-10-06
+// Last changed: 2010-05-03
 
 #ifndef __VARIATIONAL_PROBLEM_H
 #define __VARIATIONAL_PROBLEM_H
 
 #include <vector>
+#include <boost/scoped_ptr.hpp>
 #include <dolfin/common/Variable.h>
 #include <dolfin/nls/NonlinearProblem.h>
 #include <dolfin/nls/NewtonSolver.h>
@@ -108,11 +109,15 @@ namespace dolfin
     static Parameters default_parameters()
     {
       Parameters p("variational_problem");
-      
-      p.add("linear_solver", "direct");
+
+      p.add("linear_solver",  "lu");
+      p.add("preconditioner", "default");
       p.add("symmetric", false);
       p.add("reset_jacobian", true);
-      
+
+      p.add("print_rhs", false);
+      p.add("print_matrix", false);
+
       p.add(NewtonSolver::default_parameters());
       p.add(LUSolver::default_parameters());
       p.add(KrylovSolver::default_parameters());
@@ -149,7 +154,7 @@ namespace dolfin
     bool jacobian_initialised;
 
     // Newton solver
-    NewtonSolver* _newton_solver;
+    boost::scoped_ptr<NewtonSolver> _newton_solver;
   };
 
 }
