@@ -6,22 +6,24 @@
 // Modified by Andre Massing, 2009.
 //
 // First added:  2003-11-28
-// Last changed: 2010-02-12
+// Last changed: 2010-04-29
 
 #include <algorithm>
 #include <boost/assign/list_of.hpp>
 #include <boost/scoped_array.hpp>
 #include <dolfin/log/log.h>
 #include <dolfin/common/utils.h>
+#include <dolfin/common/Array.h>
 #include <dolfin/common/NoDeleter.h>
+#include <dolfin/parameter/GlobalParameters.h>
 #include <dolfin/io/File.h>
 #include <dolfin/la/GenericVector.h>
 #include <dolfin/la/DefaultFactory.h>
 #include <dolfin/fem/FiniteElement.h>
-#include <dolfin/fem/DofMap.h>
+#include <dolfin/fem/GenericDofMap.h>
+#include <dolfin/fem/DirichletBC.h>
 #include <dolfin/fem/UFC.h>
 #include <dolfin/mesh/Vertex.h>
-#include <dolfin/adaptivity/AdaptiveObjects.h>
 #include <dolfin/adaptivity/Extrapolation.h>
 #include "Data.h"
 #include "Expression.h"
@@ -33,66 +35,57 @@ using namespace dolfin;
 //-----------------------------------------------------------------------------
 Function::Function(const FunctionSpace& V)
   : _function_space(reference_to_no_delete_pointer(V)),
+    allow_extrapolation(dolfin::parameters["allow_extrapolation"]),
     local_scratch(V.element())
 {
   // Initialize vector
   init_vector();
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
 }
 //-----------------------------------------------------------------------------
 Function::Function(boost::shared_ptr<const FunctionSpace> V)
   : _function_space(V),
+    allow_extrapolation(dolfin::parameters["allow_extrapolation"]),
     local_scratch(V->element())
 {
   // Initialize vector
   init_vector();
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
 }
 //-----------------------------------------------------------------------------
 Function::Function(const FunctionSpace& V, GenericVector& x)
   : _function_space(reference_to_no_delete_pointer(V)),
     _vector(reference_to_no_delete_pointer(x)),
+    allow_extrapolation(dolfin::parameters["allow_extrapolation"]),
     local_scratch(V.element())
 {
   // Assertion uses '<=' to deal with sub-functions
   assert(V.dofmap().global_dimension() <= x.size());
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
 }
 //-----------------------------------------------------------------------------
 Function::Function(boost::shared_ptr<const FunctionSpace> V,
                    boost::shared_ptr<GenericVector> x)
   : _function_space(V),
     _vector(x),
+    allow_extrapolation(dolfin::parameters["allow_extrapolation"]),
     local_scratch(V->element())
 {
   // Assertion uses '<=' to deal with sub-functions
   assert(V->dofmap().global_dimension() <= x->size());
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
 }
 //-----------------------------------------------------------------------------
 Function::Function(boost::shared_ptr<const FunctionSpace> V,
                    GenericVector& x)
   : _function_space(V),
     _vector(reference_to_no_delete_pointer(x)),
+    allow_extrapolation(dolfin::parameters["allow_extrapolation"]),
     local_scratch(V->element())
 {
   // Assertion uses '<=' to deal with sub-functions
   assert(V->dofmap().global_dimension() <= x.size());
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
 }
 //-----------------------------------------------------------------------------
 Function::Function(const FunctionSpace& V, std::string filename)
   : _function_space(reference_to_no_delete_pointer(V)),
+    allow_extrapolation(dolfin::parameters["allow_extrapolation"]),
     local_scratch(V.element())
 {
   // Initialize vector
@@ -105,14 +98,12 @@ Function::Function(const FunctionSpace& V, std::string filename)
   // Check size of vector
   if (_vector->size() != _function_space->dim())
     error("Unable to read Function from file, number of degrees of freedom (%d) does not match dimension of function space (%d).", _vector->size(), _function_space->dim());
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
 }
 //-----------------------------------------------------------------------------
 Function::Function(boost::shared_ptr<const FunctionSpace> V,
                    std::string filename)
   : _function_space(V),
+    allow_extrapolation(dolfin::parameters["allow_extrapolation"]),
     local_scratch(V->element())
 {
   // Create vector
@@ -129,38 +120,29 @@ Function::Function(boost::shared_ptr<const FunctionSpace> V,
   // Check size of vector
   if (_vector->size() != _function_space->dim())
     error("Unable to read Function from file, number of degrees of freedom (%d) does not match dimension of function space (%d).", _vector->size(), _function_space->dim());
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
 }
 //-----------------------------------------------------------------------------
 Function::Function(const Function& v)
+  : allow_extrapolation(dolfin::parameters["allow_extrapolation"])
 {
   // Assign data
   *this = v;
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
 }
 //-----------------------------------------------------------------------------
 Function::Function(const Function& v, uint i)
-  : local_scratch(v[i]._function_space->element())
-
+  : allow_extrapolation(dolfin::parameters["allow_extrapolation"]),
+    local_scratch(v[i]._function_space->element())
 {
   // Copy function space pointer
   this->_function_space = v[i]._function_space;
 
   // Copy vector pointer
   this->_vector = v[i]._vector;
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
 }
 //-----------------------------------------------------------------------------
 Function::~Function()
 {
-  // Deregister adaptive object
-  AdaptiveObjects::deregister_object(this);
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
 const Function& Function::operator= (const Function& v)
@@ -181,33 +163,36 @@ const Function& Function::operator= (const Function& v)
   {
     // Create collapsed dof map
     std::map<uint, uint> collapsed_map;
-    boost::shared_ptr<DofMap> collapsed_dof_map(v._function_space->dofmap().collapse(collapsed_map, v._function_space->mesh()));
+    boost::shared_ptr<GenericDofMap> collapsed_dof_map(v._function_space->dofmap().collapse(collapsed_map, v._function_space->mesh()));
 
     // Create new FunctionsSpapce
     _function_space = v._function_space->collapse_sub_space(collapsed_dof_map);
-    assert(collapsed_map.size() == _function_space->dofmap().global_dimension());
 
-    // Create new vector
-    const uint size = collapsed_dof_map->global_dimension();
+    // FIXME: This assertion doesn't work in parallel
+    //assert(collapsed_map.size() == _function_space->dofmap().global_dimension());
+
+    // Create new vector (global)
     _vector.reset(v.vector().factory().create_vector());
-    _vector->resize(size);
+    _vector->resize( collapsed_dof_map->global_dimension() );
 
     // Get row indices of original and new vectors
     std::map<uint, uint>::const_iterator entry;
-    std::vector<uint> new_rows(size);
-    std::vector<uint> old_rows(size);
+    std::vector<uint> new_rows(collapsed_map.size());
+    std::vector<uint> old_rows(collapsed_map.size());
     uint i = 0;
     for (entry = collapsed_map.begin(); entry != collapsed_map.end(); ++entry)
     {
-      new_rows[i] = entry->first;
+      new_rows[i]   = entry->first;
       old_rows[i++] = entry->second;
     }
 
     // Get old values and set new values
-    v.gather();
-    std::vector<double> values(size);
-    v.get(&values[0], size, &old_rows[0]);
-    this->_vector->set(&values[0], size, &new_rows[0]);
+    std::vector<double> values(collapsed_map.size());
+    //v.gather();
+    //v.get(&values[0], collapsed_map.size(), &old_rows[0]);
+    v.vector().get(&values[0], collapsed_map.size(), &old_rows[0]);
+    this->_vector->set(&values[0], collapsed_map.size(), &new_rows[0]);
+    this->_vector->apply("insert");
   }
   local_scratch.init(this->_function_space->element());
 
@@ -284,14 +269,26 @@ void Function::eval(Array<double>& values, const Array<double>& x) const
 {
   assert(_function_space);
 
-  not_working_in_parallel("Function::eval at arbitray points.");
-
   // Find the cell that contains x
   const double* _x = x.data().get();
   Point point(_function_space->mesh().geometry().dim(), _x);
   int id = _function_space->mesh().any_intersected_entity(point);
+
+  // If not found, use the closest cell
   if (id == -1)
-    error("Unable to evaluate function at given point (not inside domain).");
+  {
+    if (allow_extrapolation)
+    {
+      id = _function_space->mesh().closest_cell(point);
+      cout << "Extrapolating function value at x = " << point << " (not inside domain)." << endl;
+    }
+    else
+    {
+      cout << "Evaluating at x = " << point << endl;
+      error("Unable to evaluate function at given point (not inside domain). Set option 'allow_extrapolation' to allow extrapolation'.");
+    }
+  }
+
 
   Cell cell(_function_space->mesh(), id);
   UFCCell ufc_cell(cell);
@@ -328,14 +325,9 @@ void Function::interpolate(const GenericFunction& v)
   function_space().interpolate(*_vector, v);
 }
 //-----------------------------------------------------------------------------
-void Function::extrapolate(const Function& v, bool facet_extrapolation)
+void Function::extrapolate(const Function& v)
 {
-  Extrapolation::extrapolate(*this, v, facet_extrapolation);
-}
-//-----------------------------------------------------------------------------
-void Function::extrapolate(const Function& v, const SubDomain& sub_domain)
-{
-  Extrapolation::extrapolate(*this, v, sub_domain);
+  Extrapolation::extrapolate(*this, v);
 }
 //-----------------------------------------------------------------------------
 dolfin::uint Function::value_rank() const
@@ -380,7 +372,7 @@ void Function::restrict(double* w,
   if (_function_space->has_element(element) && _function_space->has_cell(dolfin_cell))
   {
     // Get dofmap
-    const DofMap& dofmap = _function_space->dofmap();
+    const GenericDofMap& dofmap = _function_space->dofmap();
 
     // Tabulate dofs
     dofmap.tabulate_dofs(local_scratch.dofs, ufc_cell, dolfin_cell.index());
@@ -395,12 +387,13 @@ void Function::restrict(double* w,
   }
 }
 //-----------------------------------------------------------------------------
-void Function::compute_vertex_values(double* vertex_values,
+void Function::compute_vertex_values(Array<double>& vertex_values,
                                      const Mesh& mesh) const
 {
-  assert(vertex_values);
   assert(&mesh == &_function_space->mesh());
 
+  //vertex_values.resize(_function_space->dim());
+
   // Gather off-process dofs
   gather();
 
@@ -456,7 +449,9 @@ void Function::gather() const
       _off_process_vector.reset(_vector->factory().create_local_vector());
 
     // Gather off process coefficients
-    _vector->gather(*_off_process_vector, _off_process_dofs);
+    const Array<uint> wrapped_off_process_dofs(_off_process_dofs.size(),
+                                               &_off_process_dofs[0]);
+    _vector->gather(*_off_process_vector, wrapped_off_process_dofs);
   }
 }
 //-----------------------------------------------------------------------------
@@ -471,7 +466,7 @@ void Function::compute_off_process_dofs() const
   const Mesh& mesh = _function_space->mesh();
 
   // Storage for each cell dofs
-  const DofMap& dofmap = _function_space->dofmap();
+  const GenericDofMap& dofmap = _function_space->dofmap();
   const uint num_dofs_per_cell = _function_space->element().space_dimension();
   const uint num_dofs_global = vector().size();
   boost::scoped_array<uint> dofs(new uint[num_dofs_per_cell]);
