@@ -7,7 +7,7 @@
 // Modified by Andre Massing, 2009.
 //
 // First added:  2003-11-28
-// Last changed: 2010-02-10
+// Last changed: 2010-04-29
 
 #ifndef __FUNCTION_H
 #define __FUNCTION_H
@@ -29,11 +29,14 @@ namespace dolfin
 {
 
   // Forward declarations
+  class Data;
+  class DirichletBC;
   class Expression;
   class FunctionSpace;
   class GenericVector;
-  class Data;
   class SubDomain;
+  template<class T> class Array;
+
 
   /// This class represents a function u_h in a finite element
   /// function space V_h, given by
@@ -126,10 +129,7 @@ namespace dolfin
     void interpolate(const GenericFunction& v);
 
     /// Extrapolate function (from a possibly lower-degree function space)
-    void extrapolate(const Function& v, bool facet_extrapolation=true);
-
-    /// Extrapolate function and set equal to v in sub domain
-    void extrapolate(const Function& v, const SubDomain& sub_domain);
+    void extrapolate(const Function& v);
 
     //--- Implementation of GenericFunction interface ---
 
@@ -150,7 +150,7 @@ namespace dolfin
                           int local_facet) const;
 
     /// Compute values at all mesh vertices
-    virtual void compute_vertex_values(double* vertex_values,
+    virtual void compute_vertex_values(Array<double>& vertex_values,
                                        const Mesh& mesh) const;
 
     /// Collect off-process coefficients to prepare for interpolation
@@ -160,7 +160,6 @@ namespace dolfin
 
     // Friends
     friend class FunctionSpace;
-    friend class AdaptiveObjects;
 
     // Collection of sub-functions which share data with the function
     mutable boost::ptr_map<uint, Function> sub_functions;
@@ -185,6 +184,9 @@ namespace dolfin
     mutable std::map<uint, uint> global_to_local;
     mutable std::vector<uint> _off_process_dofs;
 
+    // True if extrapolation should be allowed
+    bool allow_extrapolation;
+
     // Scratch space, used for storing temporary local data
     class LocalScratch
     {
