@@ -8,13 +8,15 @@
 // Modified by Ola Skavhaug, 2009.
 //
 // First added:  2008-09-11
-// Last changed: 2009-11-09
+// Last changed: 2010-05-20
 
 #include <iostream>
 #include <boost/scoped_array.hpp>
 
 #include <dolfin/common/utils.h>
+#include <dolfin/common/NoDeleter.h>
 #include <dolfin/main/MPI.h>
+#include <dolfin/fem/GenericDofMap.h>
 #include <dolfin/fem/UFC.h>
 #include <dolfin/log/log.h>
 #include <dolfin/mesh/Vertex.h>
@@ -22,8 +24,7 @@
 #include <dolfin/mesh/MeshFunction.h>
 #include <dolfin/mesh/MeshPartitioning.h>
 #include <dolfin/fem/FiniteElement.h>
-#include <dolfin/fem/DofMap.h>
-#include <dolfin/adaptivity/AdaptiveObjects.h>
+#include <dolfin/fem/GenericDofMap.h>
 #include <dolfin/la/GenericVector.h>
 #include "GenericFunction.h"
 #include "Function.h"
@@ -34,55 +35,55 @@ using namespace dolfin;
 //-----------------------------------------------------------------------------
 FunctionSpace::FunctionSpace(boost::shared_ptr<const Mesh> mesh,
                              boost::shared_ptr<const FiniteElement> element,
-                             boost::shared_ptr<const DofMap> dofmap)
-  : _mesh(mesh), _element(element), _dofmap(dofmap),
-    _restriction(static_cast<MeshFunction<bool>*>(0))
+                             boost::shared_ptr<const GenericDofMap> dofmap)
+  : _mesh(mesh), _element(element), _dofmap(dofmap)
 {
-  //dolfin_debug1("Creating function space: %x", this);
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
 FunctionSpace::FunctionSpace(boost::shared_ptr<Mesh> mesh,
                              boost::shared_ptr<const FiniteElement> element,
-                             boost::shared_ptr<const DofMap> dofmap)
-  : _mesh(mesh), _element(element), _dofmap(dofmap),
-    _restriction(static_cast<MeshFunction<bool>*>(0))
+                             boost::shared_ptr<const GenericDofMap> dofmap)
+  : _mesh(mesh), _element(element), _dofmap(dofmap)
 {
-  //dolfin_debug1("Creating function space: %x", this);
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
+  // Do nothing
+}
+//-----------------------------------------------------------------------------
+FunctionSpace::FunctionSpace(boost::shared_ptr<const Mesh> mesh) : _mesh(mesh)
+{
+  // Do nothing
+}
+//-----------------------------------------------------------------------------
+FunctionSpace::FunctionSpace(boost::shared_ptr<Mesh> mesh) : _mesh(mesh)
+{
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
 FunctionSpace::FunctionSpace(const FunctionSpace& V)
 {
-  //dolfin_debug1("Creating function space: %x", this);
-
   // Assign data (will be shared)
-  _mesh    = V._mesh;
-  _element = V._element;
-  _dofmap  = V._dofmap;
-  _restriction = V._restriction;
-
-  // Register adaptive object
-  AdaptiveObjects::register_object(this);
+  *this = V;
 }
 //-----------------------------------------------------------------------------
 FunctionSpace::~FunctionSpace()
 {
-  // Deregister adaptive object
-  AdaptiveObjects::deregister_object(this);
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
-const FunctionSpace& FunctionSpace::operator= (const FunctionSpace& V)
+void FunctionSpace::attach(boost::shared_ptr<const FiniteElement> element,
+                           boost::shared_ptr<const GenericDofMap> dofmap)
+{
+  _element = element;
+  _dofmap  = dofmap;
+}
+//-----------------------------------------------------------------------------
+const FunctionSpace& FunctionSpace::operator=(const FunctionSpace& V)
 {
   // Assign data (will be shared)
-  _mesh    = V._mesh;
-  _element = V._element;
-  _dofmap  = V._dofmap;
-  _restriction = V._restriction;
+  _mesh      = V._mesh;
+  _element   = V._element;
+  _dofmap    = V._dofmap;
+  _component = V._component;
 
   return *this;
 }
@@ -99,7 +100,7 @@ const FiniteElement& FunctionSpace::element() const
   return *_element;
 }
 //-----------------------------------------------------------------------------
-const DofMap& FunctionSpace::dofmap() const
+const GenericDofMap& FunctionSpace::dofmap() const
 {
   assert(_dofmap);
   return *_dofmap;
@@ -146,7 +147,7 @@ void FunctionSpace::interpolate(GenericVector& expansion_coefficients,
   }
 
   // Finalise changes
-  expansion_coefficients.apply();
+  expansion_coefficients.apply("insert");
 }
 //-----------------------------------------------------------------------------
 boost::shared_ptr<FunctionSpace> FunctionSpace::operator[] (uint i) const
@@ -157,7 +158,7 @@ boost::shared_ptr<FunctionSpace> FunctionSpace::operator[] (uint i) const
 }
 //-----------------------------------------------------------------------------
 boost::shared_ptr<FunctionSpace>
-     FunctionSpace::extract_sub_space(const std::vector<uint>& component) const
+FunctionSpace::extract_sub_space(const std::vector<uint>& component) const
 {
   assert(_mesh);
   assert(_element);
@@ -168,7 +169,7 @@ boost::shared_ptr<FunctionSpace>
   for (uint i = 0; i < component.size(); ++i)
     identifier << component[i] << ".";
 
-  // Check if sub space is aleady in the cache
+  // Check if sub space is already in the cache
   std::map<std::string, boost::shared_ptr<FunctionSpace> >::iterator subspace;
   subspace = subspaces.find(identifier.str());
   if (subspace != subspaces.end())
@@ -178,11 +179,16 @@ boost::shared_ptr<FunctionSpace>
   boost::shared_ptr<const FiniteElement> element(_element->extract_sub_element(component));
 
   // Extract sub dofmap
-  boost::shared_ptr<DofMap> dofmap(_dofmap->extract_sub_dofmap(component, *_mesh));
+  boost::shared_ptr<GenericDofMap> dofmap(_dofmap->extract_sub_dofmap(component, *_mesh));
 
   // Create new sub space
   boost::shared_ptr<FunctionSpace> new_sub_space(new FunctionSpace(_mesh, element, dofmap));
 
+  // Set component
+  new_sub_space->_component.resize(component.size());
+  for (uint i = 0; i < component.size(); i++)
+    new_sub_space->_component[i] = component[i];
+
   // Insert new sub space into cache
   subspaces.insert(std::pair<std::string, boost::shared_ptr<FunctionSpace> >(identifier.str(), new_sub_space));
 
@@ -190,30 +196,15 @@ boost::shared_ptr<FunctionSpace>
 }
 //-----------------------------------------------------------------------------
 boost::shared_ptr<FunctionSpace>
-FunctionSpace::collapse_sub_space(boost::shared_ptr<DofMap> dofmap) const
+FunctionSpace::collapse_sub_space(boost::shared_ptr<GenericDofMap> dofmap) const
 {
   boost::shared_ptr<FunctionSpace> collapsed_sub_space(new FunctionSpace(_mesh, _element, dofmap));
   return collapsed_sub_space;
 }
 //-----------------------------------------------------------------------------
-void FunctionSpace::attach(MeshFunction<bool>& restriction)
+const dolfin::Array<dolfin::uint>& FunctionSpace::component() const
 {
-  error("FunctionSpace::attach is not working. Please fix the dof map builder.");
-}
-//-----------------------------------------------------------------------------
-boost::shared_ptr<FunctionSpace> FunctionSpace::restriction(MeshFunction<bool>& restriction)
-{
-  boost::shared_ptr<FunctionSpace> function_space(new FunctionSpace(_mesh, _element, _dofmap));
-  function_space->attach(restriction);
-  return function_space;
-}
-//-----------------------------------------------------------------------------
-bool FunctionSpace::is_inside_restriction(uint c) const
-{
-  if (_restriction)
-    return (*_restriction)[c];
-  else
-    return true;
+  return _component;
 }
 //-----------------------------------------------------------------------------
 std::string FunctionSpace::str(bool verbose) const
@@ -234,3 +225,20 @@ std::string FunctionSpace::str(bool verbose) const
   return s.str();
 }
 //-----------------------------------------------------------------------------
+void FunctionSpace::print_dofmap() const
+{
+  UFCCell ufc_cell(*_mesh);
+  for (CellIterator cell(*_mesh); !cell.end(); ++cell)
+  {
+    ufc_cell.update(*cell);
+    const uint n = _dofmap->local_dimension(ufc_cell);
+    boost::scoped_array<uint> dofs(new uint[n]);
+    _dofmap->tabulate_dofs(dofs.get(), ufc_cell, cell->index());
+
+    cout << cell->index() << ":";
+    for (uint i = 0; i < n; i++)
+      cout << " " << dofs[i];
+    cout << endl;
+  }
+}
+//-----------------------------------------------------------------------------
