@@ -6,7 +6,7 @@
 // Modified by Ola Skavhaug, 2009.
 //
 // First added:  2008-09-11
-// Last changed: 2009-11-09
+// Last changed: 2010-05-20
 
 #ifndef __FUNCTION_SPACE_H
 #define __FUNCTION_SPACE_H
@@ -16,6 +16,7 @@
 #include <vector>
 #include <boost/shared_ptr.hpp>
 #include <dolfin/common/types.h>
+#include <dolfin/common/Array.h>
 #include <dolfin/common/Variable.h>
 #include <dolfin/mesh/MeshFunction.h>
 #include <dolfin/fem/FiniteElement.h>
@@ -25,7 +26,7 @@ namespace dolfin
 
   class Mesh;
   class Cell;
-  class DofMap;
+  class GenericDofMap;
   class Function;
   class GenericFunction;
   class GenericVector;
@@ -42,12 +43,24 @@ namespace dolfin
     /// Create function space for given mesh, element and dofmap (shared data)
     FunctionSpace(boost::shared_ptr<Mesh> mesh,
                   boost::shared_ptr<const FiniteElement> element,
-                  boost::shared_ptr<const DofMap> dofmap);
+                  boost::shared_ptr<const GenericDofMap> dofmap);
 
     /// Create function space for given mesh, element and dofmap (shared data)
     FunctionSpace(boost::shared_ptr<const Mesh> mesh,
                   boost::shared_ptr<const FiniteElement> element,
-                  boost::shared_ptr<const DofMap> dofmap);
+                  boost::shared_ptr<const GenericDofMap> dofmap);
+
+  protected:
+
+    /// Create an empty function space for later intialisation. This
+    /// constructor is intended for use by any sub-classes which need to
+    /// construct objects before the initialisation of the base class. Data can
+    /// be attached to the base class using FunctionSpace::attach(...)
+    FunctionSpace(boost::shared_ptr<Mesh> mesh);
+
+    FunctionSpace(boost::shared_ptr<const Mesh> mesh);
+
+  public:
 
     /// Copy constructor
     FunctionSpace(const FunctionSpace& V);
@@ -55,6 +68,14 @@ namespace dolfin
     /// Destructor
     virtual ~FunctionSpace();
 
+  protected:
+
+    /// Attach data to an empty FunctionSpace
+    void attach(boost::shared_ptr<const FiniteElement> element,
+                boost::shared_ptr<const GenericDofMap> dofmap);
+
+  public:
+
     /// Assignment operator
     const FunctionSpace& operator= (const FunctionSpace& V);
 
@@ -65,26 +86,26 @@ namespace dolfin
     const FiniteElement& element() const;
 
     /// Return dofmap
-    const DofMap& dofmap() const;
+    const GenericDofMap& dofmap() const;
 
     /// Return dimension of function space
     uint dim() const;
 
-    /// Interpolate function v into function space, returning the vector of 
+    /// Interpolate function v into function space, returning the vector of
     /// expansion coefficients
-    void interpolate(GenericVector& expansion_coefficients, 
+    void interpolate(GenericVector& expansion_coefficients,
                      const GenericFunction& v) const;
 
     /// Extract sub space for component
     boost::shared_ptr<FunctionSpace> operator[] (uint i) const;
 
     /// Extract sub space for component
-    boost::shared_ptr<FunctionSpace> 
-                  extract_sub_space(const std::vector<uint>& component) const;
+    boost::shared_ptr<FunctionSpace>
+    extract_sub_space(const std::vector<uint>& component) const;
 
     /// Return function space with a new dof map
     boost::shared_ptr<FunctionSpace>
-    collapse_sub_space(boost::shared_ptr<DofMap> dofmap) const;
+    collapse_sub_space(boost::shared_ptr<GenericDofMap> dofmap) const;
 
     /// Check if function space has given cell
     bool has_cell(const Cell& cell) const
@@ -98,23 +119,19 @@ namespace dolfin
       return element.hash() == _element->hash();
     }
 
-    /// Attach restriction meshfunction
-    void attach(MeshFunction<bool>& restriction);
-
-    /// Create function space based on the restriction
-    boost::shared_ptr<FunctionSpace> restriction(MeshFunction<bool>& restriction);
-
-    // Evaluate restriction
-    bool is_inside_restriction(uint c) const;
+    /// Return component (relative to super space)
+    const Array<uint>& component() const;
 
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const;
 
+    /// Print dofmap (useful for debugging)
+    void print_dofmap() const;
+
   private:
 
     // Friends
     friend class Function;
-    friend class AdaptiveObjects;
 
     // The mesh
     boost::shared_ptr<const Mesh> _mesh;
@@ -123,10 +140,10 @@ namespace dolfin
     boost::shared_ptr<const FiniteElement> _element;
 
     // The dofmap
-    boost::shared_ptr<const DofMap> _dofmap;
+    boost::shared_ptr<const GenericDofMap> _dofmap;
 
-    // The restriction meshfunction
-    boost::shared_ptr<const MeshFunction<bool> > _restriction;
+    // The component (for sub spaces)
+    Array<uint> _component;
 
     // Cache of sub spaces
     mutable std::map<std::string, boost::shared_ptr<FunctionSpace> > subspaces;
