@@ -2,7 +2,7 @@
 // Licensed under the GNU LGPL Version 2.1.
 //
 // First added:  2009-11-11
-// Last changed: 2010-02-10
+// Last changed: 2010-04-29
 
 #ifndef __BINARY_FILE_H
 #define __BINARY_FILE_H
@@ -56,6 +56,44 @@ namespace dolfin
     /// Write mesh
     void operator<< (const Mesh& mesh);
 
+  private:
+
+    // Open file for reading
+    void open_read();
+
+    // Open file for writing
+    void open_write();
+
+    // Close file for reading
+    void close_read();
+
+    // Close file for writing
+    void close_write();
+
+    // Read uint
+    uint read_uint();
+
+    // Read array (uint)
+    void read_array(uint n, uint* values);
+
+    // Read array (double)
+    void read_array(uint n, double* values);
+
+    // Write uint
+    void write_uint(uint value);
+
+    // Write array (uint)
+    void write_array(uint n, const uint* values);
+
+    // Write array (double)
+    void write_array(uint n, const double* values);
+
+    // File for reading
+    std::ifstream ifile;
+
+    // File for writing
+    std::ofstream ofile;
+
   };
 
 }
