@@ -14,6 +14,7 @@
 
 #include <ostream>
 #include <string>
+#include <utility>
 #include "GenericFile.h"
 
 namespace dolfin
@@ -55,6 +56,9 @@ namespace dolfin
     /// Write Function to file
     void operator<<(const Function& u);
 
+    /// Write Function to file (with time)
+    void operator<<(const std::pair<const Function*, double> u);
+
     /// Write to file
     template<class T> void operator<<(const T& t)
     {
