@@ -7,24 +7,25 @@
 // Modified by Niclas Jansson 2009.
 //
 // First added:  2005-07-05
-// Last changed: 2009-10-08
+// Last changed: 2010-06-21
 
-#include <vector>
+#include <ostream>
 #include <sstream>
-#include <fstream>
+#include <vector>
 #include <boost/cstdint.hpp>
 #include <boost/detail/endian.hpp>
 
+#include <dolfin/common/Array.h>
+#include <dolfin/fem/GenericDofMap.h>
+#include <dolfin/fem/FiniteElement.h>
+#include <dolfin/function/Function.h>
+#include <dolfin/function/FunctionSpace.h>
+#include <dolfin/la/GenericVector.h>
+#include <dolfin/la/LinearAlgebraFactory.h>
+#include <dolfin/mesh/Cell.h>
 #include <dolfin/mesh/Mesh.h>
 #include <dolfin/mesh/MeshFunction.h>
 #include <dolfin/mesh/Vertex.h>
-#include <dolfin/mesh/Cell.h>
-#include <dolfin/la/GenericVector.h>
-#include <dolfin/la/LinearAlgebraFactory.h>
-#include <dolfin/fem/FiniteElement.h>
-#include <dolfin/fem/DofMap.h>
-#include <dolfin/function/Function.h>
-#include <dolfin/function/FunctionSpace.h>
 #include "Encoder.h"
 #include "VTKFile.h"
 
@@ -62,17 +63,14 @@ void VTKFile::operator<<(const Mesh& mesh)
   if (MPI::num_processes() > 1 && MPI::process_number() == 0)
   {
     std::string pvtu_filename = vtu_name(0, 0, counter, ".pvtu");
-
-    // Write parallel Mesh
     pvtu_mesh_write(pvtu_filename, vtu_filename);
-
   }
 
   // Finalise and write pvd files
-  finalize(vtu_filename);
+  finalize(vtu_filename, counter);
 
-  info(1, "Saved mesh %s (%s) to file %s in VTK format.",
-          mesh.name().c_str(), mesh.label().c_str(), filename.c_str());
+  info(TRACE, "Saved mesh %s (%s) to file %s in VTK format.",
+       mesh.name().c_str(), mesh.label().c_str(), filename.c_str());
 }
 //----------------------------------------------------------------------------
 void VTKFile::operator<<(const MeshFunction<bool>& meshfunction)
@@ -96,13 +94,23 @@ void VTKFile::operator<<(const MeshFunction<double>& meshfunction)
 }
 //----------------------------------------------------------------------------
 void VTKFile::operator<<(const Function& u)
+{
+  write(u, counter);
+}
+//----------------------------------------------------------------------------
+void VTKFile::operator<<(const std::pair<const Function*, double> u)
+{
+  write(*(u.first), u.second);
+}
+//----------------------------------------------------------------------------
+void VTKFile::write(const Function& u, double time)
 {
   const Mesh& mesh = u.function_space().mesh();
 
   // Get vtu file name and intialise
   std::string vtu_filename = init(mesh);
 
-  // Write Mesh
+  // Write mesh
   mesh_write(mesh, vtu_filename);
 
   // Write results
@@ -112,25 +120,24 @@ void VTKFile::operator<<(const Function& u)
   if (MPI::num_processes() > 1 && MPI::process_number() == 0)
   {
     std::string pvtu_filename = vtu_name(0, 0, counter, ".pvtu");
-
-    // Write parallel Mesh
     pvtu_mesh_write(pvtu_filename, vtu_filename);
-
-    // Write results
     pvtu_results_write(u, pvtu_filename);
   }
 
   // Finalise and write pvd files
-  finalize(vtu_filename);
+  finalize(vtu_filename, time);
 
-  info(1, "Saved function %s (%s) to file %s in VTK format.",
-          u.name().c_str(), u.label().c_str(), filename.c_str());
+  info(TRACE, "Saved function %s (%s) to file %s in VTK format.",
+       u.name().c_str(), u.label().c_str(), filename.c_str());
 }
 //----------------------------------------------------------------------------
 std::string VTKFile::init(const Mesh& mesh) const
 {
   // Get vtu file name and clear file
-  std::string vtu_filename = vtu_name(MPI::process_number(), MPI::num_processes(), counter, ".vtu");
+  std::string vtu_filename = vtu_name(MPI::process_number(),
+                                      MPI::num_processes(),
+                                      counter,
+                                      ".vtu");
   clear_file(vtu_filename);
 
   // Write headers
@@ -141,14 +148,13 @@ std::string VTKFile::init(const Mesh& mesh) const
     // Get pvtu file name and clear file
     std::string pvtu_filename = vtu_name(0, 0, counter, ".pvtu");
     clear_file(pvtu_filename);
-
     pvtu_header_open(pvtu_filename);
   }
 
   return vtu_filename;
 }
 //----------------------------------------------------------------------------
-void VTKFile::finalize(std::string vtu_filename)
+void VTKFile::finalize(std::string vtu_filename, double time)
 {
   // Close headers
   vtk_header_close(vtu_filename);
@@ -163,14 +169,11 @@ void VTKFile::finalize(std::string vtu_filename)
       pvtu_header_close(pvtu_filename);
 
       // Write pvd file (parallel)
-      pvd_file_write(counter, pvtu_filename);
+      pvd_file_write(counter, counter, pvtu_filename);
     }
   }
   else
-  {
-    // Write pvd file (serial)
-    pvd_file_write(counter, vtu_filename);
-  }
+    pvd_file_write(counter, time, vtu_filename);
 
   // Increase the number of times we have saved the object
   counter++;
@@ -179,25 +182,24 @@ void VTKFile::finalize(std::string vtu_filename)
 void VTKFile::mesh_write(const Mesh& mesh, std::string vtu_filename) const
 {
   // Open file
-  FILE* fp = fopen(vtu_filename.c_str(), "a");
-  if (!fp)
+  std::ofstream file(vtu_filename.c_str(), std::ios::app);
+  if ( !file.is_open() )
     error("Unable to open file %s", filename.c_str());
 
   // Write vertex positions
-  fprintf(fp, "<Points>  \n");
-  fprintf(fp, "<DataArray  type=\"Float32\"  NumberOfComponents=\"3\"  format=\"%s\">  \n", encode_string.c_str());
+  file << "<Points>" << std::endl;
+  file << "<DataArray  type=\"Float32\"  NumberOfComponents=\"3\"  format=\"" << encode_string << "\">" << std::endl;
   if (encoding == "ascii")
   {
     for (VertexIterator v(mesh); !v.end(); ++v)
     {
       Point p = v->point();
-      fprintf(fp," %f %f %f \n", p.x(), p.y(), p.z());
+      file << p.x() << " " << p.y() << " " <<  p.z() << std::endl;
     }
   }
   else if (encoding == "base64" || encoding == "compressed")
   {
-    std::vector<float> data;
-    data.resize(3*mesh.num_vertices());
+    std::vector<float> data(3*mesh.num_vertices());
     std::vector<float>::iterator entry = data.begin();
     for (VertexIterator v(mesh); !v.end(); ++v)
     {
@@ -209,29 +211,26 @@ void VTKFile::mesh_write(const Mesh& mesh, std::string vtu_filename) const
     // Create encoded stream
     std::stringstream base64_stream;
     encode_stream(base64_stream, data);
-    fprintf(fp, "%s", base64_stream.str().c_str());
-    fprintf(fp, "\n");
+    file <<  base64_stream.str() << std::endl;
   }
-  fprintf(fp, "</DataArray>  \n");
-  fprintf(fp, "</Points>  \n");
+  file << "</DataArray>" << std::endl <<  "</Points>" << std::endl;
 
   // Write cell connectivity
-  fprintf(fp, "<Cells>  \n");
-  fprintf(fp, "<DataArray  type=\"UInt32\"  Name=\"connectivity\"  format=\"%s\">  \n", encode_string.c_str());
+  file << "<Cells>" << std::endl;
+  file << "<DataArray  type=\"UInt32\"  Name=\"connectivity\"  format=\"" << encode_string << "\">" << std::endl;
   if (encoding == "ascii")
   {
     for (CellIterator c(mesh); !c.end(); ++c)
     {
       for (VertexIterator v(*c); !v.end(); ++v)
-        fprintf(fp," %8u ",v->index());
-      fprintf(fp," \n");
+        file << v->index() << " ";
+      file << std::endl;
     }
   }
   else if (encoding == "base64" || encoding == "compressed")
   {
     const int size = mesh.num_cells()*mesh.type().num_entities(0);
-    std::vector<boost::uint32_t> data;
-    data.resize(size);
+    std::vector<boost::uint32_t> data(size);
     std::vector<boost::uint32_t>::iterator entry = data.begin();
     for (CellIterator c(mesh); !c.end(); ++c)
     {
@@ -242,23 +241,21 @@ void VTKFile::mesh_write(const Mesh& mesh, std::string vtu_filename) const
     // Create encoded stream
     std::stringstream base64_stream;
     encode_stream(base64_stream, data);
-    fprintf(fp, "%s", base64_stream.str().c_str());
-    fprintf(fp, "\n");
+    file << base64_stream.str() << std::endl;
   }
-  fprintf(fp, "</DataArray> \n");
+  file << "</DataArray>" << std::endl;
 
   // Write offset into connectivity array for the end of each cell
-  fprintf(fp, "<DataArray  type=\"UInt32\"  Name=\"offsets\"  format=\"%s\">  \n", encode_string.c_str());
+  file << "<DataArray  type=\"UInt32\"  Name=\"offsets\"  format=\"" << encode_string << "\">" << std::endl;
   const uint num_cell_vertices = mesh.type().num_entities(0);
   if (encoding == "ascii")
   {
     for (uint offsets = 1; offsets <= mesh.num_cells(); offsets++)
-      fprintf(fp, " %8u \n",  offsets*num_cell_vertices);
+      file << " " << offsets*num_cell_vertices << "  "  << std::endl;
   }
   else if (encoding == "base64" || encoding == "compressed")
   {
-    std::vector<boost::uint32_t> data;
-    data.resize(mesh.num_cells()*num_cell_vertices);
+    std::vector<boost::uint32_t> data(mesh.num_cells()*num_cell_vertices);
     std::vector<boost::uint32_t>::iterator entry = data.begin();
     for (uint offsets = 1; offsets <= mesh.num_cells(); offsets++)
       *entry++ = offsets*num_cell_vertices;
@@ -266,13 +263,12 @@ void VTKFile::mesh_write(const Mesh& mesh, std::string vtu_filename) const
     // Create encoded stream
     std::stringstream base64_stream;
     encode_stream(base64_stream, data);
-    fprintf(fp, "%s", base64_stream.str().c_str());
-    fprintf(fp, "\n");
+    file << base64_stream.str() << std::endl;
   }
-  fprintf(fp, "</DataArray> \n");
+  file << "</DataArray>" << std::endl;
 
   //Write cell type
-  fprintf(fp, "<DataArray  type=\"UInt8\"  Name=\"types\"  format=\"%s\">  \n", encode_string.c_str());
+  file << "<DataArray  type=\"UInt8\"  Name=\"types\"  format=\"" << encode_string << "\">" << std::endl;
   boost::uint8_t vtk_cell_type = 0;
   if (mesh.type().cell_type() == CellType::tetrahedron)
     vtk_cell_type = boost::uint8_t(10);
@@ -283,12 +279,11 @@ void VTKFile::mesh_write(const Mesh& mesh, std::string vtu_filename) const
   if (encoding == "ascii")
   {
     for (uint types = 0; types < mesh.num_cells(); types++)
-      fprintf(fp, " %8u \n", vtk_cell_type);
+      file << " " << static_cast<unsigned int>(vtk_cell_type) << std::endl;
   }
   else if (encoding == "base64" || encoding == "compressed")
   {
-    std::vector<boost::uint8_t> data;
-    data.resize(mesh.num_cells());
+    std::vector<boost::uint8_t> data(mesh.num_cells());
     std::vector<boost::uint8_t>::iterator entry = data.begin();
     for (uint types = 0; types < mesh.num_cells(); types++)
       *entry++ = vtk_cell_type;
@@ -296,15 +291,13 @@ void VTKFile::mesh_write(const Mesh& mesh, std::string vtu_filename) const
     // Create encoded stream
     std::stringstream base64_stream;
     encode_stream(base64_stream, data);
-
-    fprintf(fp, "%s", base64_stream.str().c_str());
-    fprintf(fp, "\n");
+    file << base64_stream.str() << std::endl;
   }
-  fprintf(fp, "</DataArray> \n");
-  fprintf(fp, "</Cells> \n");
+  file  << "</DataArray>" << std::endl;
+  file  << "</Cells>" << std::endl;
 
   // Close file
-  fclose(fp);
+  file.close();
 }
 //----------------------------------------------------------------------------
 void VTKFile::results_write(const Function& u, std::string vtu_filename) const
@@ -337,8 +330,7 @@ void VTKFile::results_write(const Function& u, std::string vtu_filename) const
   for (uint i = 0; i < rank; i++)
     cell_based_dim *= mesh.topology().dim();
 
-
-  const DofMap& dofmap(u.function_space().dofmap());
+  const GenericDofMap& dofmap(u.function_space().dofmap());
   if (dofmap.max_local_dimension() == cell_based_dim)
     write_cell_data(u, vtu_filename);
   else
@@ -360,25 +352,25 @@ void VTKFile::write_point_data(const GenericFunction& u, const Mesh& mesh,
 
   // Allocate memory for function values at vertices
   const uint size = mesh.num_vertices()*dim;
-  std::vector<double> values(size);
-
-  // Get function values at vertices
-  u.compute_vertex_values(&values[0], mesh);
+  Array<double> values(size);
 
+  // Get function values at vertices and zero any small values
+  u.compute_vertex_values(values, mesh);
+  values.zero_eps(DOLFIN_EPS);
   if (rank == 0)
   {
-    fp << "<PointData  Scalars=\"U\"> " << std::endl;
-    fp << "<DataArray  type=\"Float32\"  Name=\"U\"  format=\""<< encode_string <<"\">" << std::endl;
+    fp << "<PointData  Scalars=\"" << u.name() << "\"> " << std::endl;
+    fp << "<DataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  format=\""<< encode_string <<"\">" << std::endl;
   }
   else if (rank == 1)
   {
-    fp << "<PointData  Vectors=\"U\"> " << std::endl;
-    fp << "<DataArray  type=\"Float32\"  Name=\"U\"  NumberOfComponents=\"3\" format=\""<< encode_string <<"\">" << std::endl;
+    fp << "<PointData  Vectors=\"" << u.name() << "\"> " << std::endl;
+    fp << "<DataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  NumberOfComponents=\"3\" format=\""<< encode_string <<"\">" << std::endl;
   }
   else if (rank == 2)
   {
-    fp << "<PointData  Tensors=\"U\"> " << std::endl;
-    fp << "<DataArray  type=\"Float32\"  Name=\"U\"  NumberOfComponents=\"9\" format=\""<< encode_string <<"\">" << std::endl;
+    fp << "<PointData  Tensors=\"" << u.name() << "\"> " << std::endl;
+    fp << "<DataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  NumberOfComponents=\"9\" format=\""<< encode_string <<"\">" << std::endl;
   }
 
   if (encoding == "ascii")
@@ -436,8 +428,8 @@ void VTKFile::write_point_data(const GenericFunction& u, const Mesh& mesh,
       {
         // Append 0.0 to 2D vectors to make them 3D
         for(uint i = 0; i < dim; i++)
-          *entry++ = values[vertex->index() + i*mesh.num_vertices()];
-        *entry++ = 0.0;
+          *(entry++) = values[vertex->index() + i*mesh.num_vertices()];
+        *(entry++) = 0.0;
       }
       else if (rank == 2 && dim == 4)
       {
@@ -476,8 +468,8 @@ void VTKFile::write_point_data(const GenericFunction& u, const Mesh& mesh,
 void VTKFile::write_cell_data(const Function& u, std::string vtu_filename) const
 {
   // For brevity
-  const Mesh& mesh(u.function_space().mesh());
-  const DofMap& dofmap(u.function_space().dofmap());
+  const Mesh& mesh = u.function_space().mesh();
+  const GenericDofMap& dofmap = u.function_space().dofmap();
 
   // Get rank of Function
   const uint rank = u.value_rank();
@@ -495,18 +487,18 @@ void VTKFile::write_cell_data(const Function& u, std::string vtu_filename) const
   // Write headers
   if (rank == 0)
   {
-    fp << "<CellData  Scalars=\"U\"> " << std::endl;
-    fp << "<DataArray  type=\"Float32\"  Name=\"U\"  format=\""<< encode_string <<"\">" << std::endl;
+    fp << "<CellData  Scalars=\"" << u.name() << "\"> " << std::endl;
+    fp << "<DataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  format=\""<< encode_string <<"\">" << std::endl;
   }
   else if (rank == 1)
   {
-    fp << "<CellData  Vectors=\"U\"> " << std::endl;
-    fp << "<DataArray  type=\"Float32\"  Name=\"U\"  NumberOfComponents=\"3\" format=\""<< encode_string <<"\">" << std::endl;
+    fp << "<CellData  Vectors=\"" << u.name() << "\"> " << std::endl;
+    fp << "<DataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  NumberOfComponents=\"3\" format=\""<< encode_string <<"\">" << std::endl;
   }
   else if (rank == 2)
   {
-    fp << "<CellData  Tensors=\"U\"> " << std::endl;
-    fp << "<DataArray  type=\"Float32\"  Name=\"U\"  NumberOfComponents=\"9\" format=\""<< encode_string <<"\">" << std::endl;
+    fp << "<CellData  Tensors=\"" << u.name() << "\"> " << std::endl;
+    fp << "<DataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  NumberOfComponents=\"9\" format=\""<< encode_string <<"\">" << std::endl;
   }
 
   // Allocate memory for function values at cell centres
@@ -637,11 +629,11 @@ void VTKFile::write_cell_data(const Function& u, std::string vtu_filename) const
   fp << "</CellData> " << std::endl;
 }
 //----------------------------------------------------------------------------
-void VTKFile::pvd_file_write(uint num, std::string _filename)
+void VTKFile::pvd_file_write(uint step, double time, std::string _filename)
 {
   std::fstream pvd_file;
 
-  if( num == 0)
+  if (step == 0)
   {
     // Open pvd file
     pvd_file.open(filename.c_str(), std::ios::out|std::ios::trunc);
@@ -654,7 +646,7 @@ void VTKFile::pvd_file_write(uint num, std::string _filename)
   else
   {
     // Open pvd file
-    pvd_file.open(filename.c_str(),  std::ios::out|std::ios::in);
+    pvd_file.open(filename.c_str(), std::ios::out|std::ios::in);
     pvd_file.seekp(mark);
   }
 
@@ -662,7 +654,7 @@ void VTKFile::pvd_file_write(uint num, std::string _filename)
   std::string fname = strip_path(_filename);
 
   // Data file name
-  pvd_file << "<DataSet timestep=\"" << num << "\" part=\"0\"" << " file=\"" <<  fname <<  "\"/>" << std::endl;
+  pvd_file << "<DataSet timestep=\"" << time << "\" part=\"0\"" << " file=\"" <<  fname <<  "\"/>" << std::endl;
   mark = pvd_file.tellp();
 
   // Close headers
@@ -673,11 +665,12 @@ void VTKFile::pvd_file_write(uint num, std::string _filename)
   pvd_file.close();
 }
 //----------------------------------------------------------------------------
-void VTKFile::pvtu_mesh_write(std::string pvtu_filename, std::string vtu_filename) const
+void VTKFile::pvtu_mesh_write(std::string pvtu_filename,
+                              std::string vtu_filename) const
 {
   // Open pvtu file
-  std::fstream pvtu_file;
-  pvtu_file.open(pvtu_filename.c_str(), std::ios::out|std::ios::app);
+  std::ofstream pvtu_file;
+  pvtu_file.open(pvtu_filename.c_str(), std::ios::app);
 
   pvtu_file << "<PCellData>" << std::endl;
   pvtu_file << "<PDataArray  type=\"UInt32\"  Name=\"connectivity\"/>" << std::endl;
@@ -705,9 +698,9 @@ void VTKFile::pvtu_results_write(const Function& u, std::string pvtu_filename) c
 
   // For brevity
   const FunctionSpace& V = u.function_space();
-  const Mesh& mesh(V.mesh());
-  const FiniteElement& element(V.element());
-  const DofMap& dofmap(V.dofmap());
+  const Mesh& mesh = V.mesh();
+  const FiniteElement& element = V.element();
+  const GenericDofMap& dofmap = V.dofmap();
 
   // Get rank of Function
   const uint rank = element.value_rank();
@@ -727,69 +720,64 @@ void VTKFile::pvtu_results_write(const Function& u, std::string pvtu_filename) c
     data_type = "cell";
 
   // Open pvtu file
-  std::fstream pvtu_file;
-  pvtu_file.open(pvtu_filename.c_str(), std::ios::out|std::ios::app);
+  std::ofstream pvtu_file(pvtu_filename.c_str(), std::ios::app);
 
   // Write function data at mesh cells
   if (data_type == "cell")
   {
-
     // Write headers
     if (rank == 0)
     {
-      pvtu_file << "<PCellData  Scalars=\"U\"> " << std::endl;
-      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"U\">" << std::endl;
+      pvtu_file << "<PCellData  Scalars=\"" << u.name() << "\"> " << std::endl;
+      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"" << u.name() << "\">" << std::endl;
     }
     else if (rank == 1)
     {
-      if(!(dim == 2 || dim == 3))
-        error("don't know what to do with vector function with dim other than 2 or 3.");
-      pvtu_file << "<PCellData  Vectors=\"U\"> " << std::endl;
-      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"U\"  NumberOfComponents=\"3\">" << std::endl;
+      if (!(dim == 2 || dim == 3))
+        error("Do not know what to do with vector function with dim other than 2 or 3.");
+      pvtu_file << "<PCellData  Vectors=\"" << u.name() << "\"> " << std::endl;
+      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  NumberOfComponents=\"3\">" << std::endl;
     }
     else if (rank == 2)
     {
       if(!(dim == 4 || dim == 9))
         error("Don't know what to do with tensor function with dim other than 4 or 9.");
-      pvtu_file << "<PCellData  Tensors=\"U\"> " << std::endl;
-      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"U\"  NumberOfComponents=\"9\">" << std::endl;
+      pvtu_file << "<PCellData  Tensors=\"" << u.name() << "\"> " << std::endl;
+      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  NumberOfComponents=\"9\">" << std::endl;
     }
-
     pvtu_file << "</PDataArray> " << std::endl;
     pvtu_file << "</PCellData> " << std::endl;
-
   }
   else if (data_type == "point")
   {
     if (rank == 0)
     {
-      pvtu_file << "<PPointData  Scalars=\"U\"> " << std::endl;
-      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"U\">" << std::endl;
+      pvtu_file << "<PPointData  Scalars=\"" << u.name() << "\"> " << std::endl;
+      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"" << u.name() << "\">" << std::endl;
     }
     else if (rank == 1)
     {
-      pvtu_file << "<PPointData  Vectors=\"U\"> " << std::endl;
-      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"U\"  NumberOfComponents=\"3\">" << std::endl;
+      pvtu_file << "<PPointData  Vectors=\"" << u.name() << "\"> " << std::endl;
+      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  NumberOfComponents=\"3\">" << std::endl;
     }
     else if (rank == 2)
     {
-      pvtu_file << "<PPointData  Tensors=\"U\"> " << std::endl;
-      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"U\"  NumberOfComponents=\"9\">" << std::endl;
+      pvtu_file << "<PPointData  Tensors=\"" << u.name() << "\"> " << std::endl;
+      pvtu_file << "<PDataArray  type=\"Float32\"  Name=\"" << u.name() << "\"  NumberOfComponents=\"9\">" << std::endl;
     }
-
     pvtu_file << "</PDataArray> " << std::endl;
     pvtu_file << "</PPointData> " << std::endl;
   }
 
-    pvtu_file.close();
+  pvtu_file.close();
 }
 //----------------------------------------------------------------------------
 void VTKFile::vtk_header_open(uint num_vertices, uint num_cells,
                               std::string vtu_filename) const
 {
   // Open file
-  FILE *fp = fopen(vtu_filename.c_str(), "a");
-  if (!fp)
+  std::ofstream file(vtu_filename.c_str(), std::ios::app);
+  if ( !file.is_open() )
     error("Unable to open file %s", filename.c_str());
 
   // Figure out endianness of machine
@@ -811,35 +799,33 @@ void VTKFile::vtk_header_open(uint num_vertices, uint num_cells,
     compressor = "compressor=\"vtkZLibDataCompressor\"";
 
   // Write headers
-  fprintf(fp, "<?xml version=\"1.0\"?> \n");
-  fprintf(fp, "<VTKFile type=\"UnstructuredGrid\"  version=\"0.1\" %s  %s>\n", endianness.c_str(), compressor.c_str());
-  fprintf(fp, "<UnstructuredGrid>  \n");
-  fprintf(fp, "<Piece  NumberOfPoints=\" %8u\"  NumberOfCells=\" %8u\">  \n",
-          num_vertices, num_cells);
+  file << "<?xml version=\"1.0\"?>" << std::endl;
+  file << "<VTKFile type=\"UnstructuredGrid\"  version=\"0.1\" " << endianness <<  " " << compressor << ">" << std::endl;
+  file << "<UnstructuredGrid>" << std::endl;
+  file << "<Piece  NumberOfPoints=\"" << num_vertices << "\" NumberOfCells=\"" << num_cells << "\">" << std::endl;
 
   // Close file
-  fclose(fp);
+  file.close();
 }
 //----------------------------------------------------------------------------
 void VTKFile::vtk_header_close(std::string vtu_filename) const
 {
   // Open file
-  FILE *fp = fopen(vtu_filename.c_str(), "a");
-  if (!fp)
+  std::ofstream file(vtu_filename.c_str(), std::ios::app);
+  if ( !file.is_open() )
     error("Unable to open file %s", filename.c_str());
 
   // Close headers
-  fprintf(fp, "</Piece> \n</UnstructuredGrid> \n</VTKFile>");
+  file << "</Piece>" << std::endl << "</UnstructuredGrid>" << std::endl << "</VTKFile>";
 
   // Close file
-  fclose(fp);
+  file.close();
 }
 //----------------------------------------------------------------------------
 void VTKFile::pvtu_header_open(std::string pvtu_filename) const
 {
   // Open pvtu file
-  std::fstream pvtu_file;
-  pvtu_file.open(pvtu_filename.c_str(), std::ios::out|std::ios::trunc);
+  std::ofstream pvtu_file(pvtu_filename.c_str(), std::ios::trunc);
 
   // Write header
   pvtu_file << "<?xml version=\"1.0\"?>" << std::endl;
@@ -851,8 +837,7 @@ void VTKFile::pvtu_header_open(std::string pvtu_filename) const
 void VTKFile::pvtu_header_close(std::string pvtu_filename) const
 {
   // Open pvtu file
-  std::fstream pvtu_file;
-  pvtu_file.open(pvtu_filename.c_str(), std::ios::out|std::ios::app);
+  std::ofstream pvtu_file(pvtu_filename.c_str(), std::ios::app);
 
   pvtu_file << "</PUnstructuredGrid>" << std::endl;
   pvtu_file << "</VTKFile>" << std::endl;
@@ -902,8 +887,8 @@ void VTKFile::mesh_function_write(T& meshfunction)
   // Open file
   std::ofstream fp(vtu_filename.c_str(), std::ios_base::app);
 
-  fp << "<CellData  Scalars=\"U\">" << std::endl;
-  fp << "<DataArray  type=\"Float32\"  Name=\"U\"  format=\"ascii\">" << std::endl;
+  fp << "<CellData  Scalars=\"" << meshfunction.name() << "\">" << std::endl;
+  fp << "<DataArray  type=\"Float32\"  Name=\"" << meshfunction.name() << "\"  format=\"ascii\">" << std::endl;
   for (CellIterator cell(mesh); !cell.end(); ++cell)
     fp << meshfunction[cell->index()] << std::endl;
   fp << "</DataArray>" << std::endl;
@@ -913,7 +898,7 @@ void VTKFile::mesh_function_write(T& meshfunction)
   fp.close();
 
   // Write pvd files
-  finalize(vtu_filename);
+  finalize(vtu_filename, counter);
 
   cout << "saved mesh function " << counter << " times." << endl;
 
@@ -923,10 +908,11 @@ void VTKFile::mesh_function_write(T& meshfunction)
 //----------------------------------------------------------------------------
 void VTKFile::clear_file(std::string file) const
 {
-  FILE* fp = fopen(file.c_str(), "w");
-  if (!fp)
+  // Open file and clear
+  std::ofstream _file(file.c_str(), std::ios::trunc);
+  if ( !_file.is_open() )
     error("Unable to open file %s", file.c_str());
-  fclose(fp);
+  _file.close();
 }
 //----------------------------------------------------------------------------
 std::string VTKFile::strip_path(std::string file) const
@@ -986,4 +972,3 @@ void VTKFile::encode_inline_compressed_base64(std::stringstream& stream,
 }
 #endif
 //----------------------------------------------------------------------------
-
