@@ -4,7 +4,7 @@
 // Modified by Garth N. Wells, 2009.
 //
 // First added: 2009-03-03
-// Last changed: 2010-01-04
+// Last changed: 2010-04-05
 
 #include <libxml/relaxng.h>
 
@@ -92,15 +92,13 @@ void XMLFile::validate(const std::string filename)
                                      (xmlStructuredErrorFunc)rng_valid_error,
                                      stderr);
   ret = xmlRelaxNGValidateDoc(validator, document);
-  if ( ret == 0 ) {
-    info(0, "%s validates", filename.c_str());
-  }
-  else if ( ret < 0 ) {
+  if (ret == 0)
+    info(DBG, "%s validates", filename.c_str());
+  else if ( ret < 0 )
     error("%s failed to load", filename.c_str());
-  }
-  else {
+  else
     error("%s fails to validate", filename.c_str());
-  }
+
   xmlRelaxNGFreeValidCtxt(validator);
 }
 //-----------------------------------------------------------------------------
