@@ -13,19 +13,25 @@
 
 #include <map>
 #include <string>
+#include <boost/shared_ptr.hpp>
+#include <dolfin/common/NoDeleter.h>
 #include <dolfin/common/types.h>
 #include "GenericLinearSolver.h"
 
+// Forward declarations
+class AztecOO;
+
 namespace dolfin
 {
 
-  /// Forward declarations
+  // Forward declarations
   class GenericMatrix;
   class GenericVector;
   class EpetraMatrix;
   class EpetraVector;
   class EpetraKrylovMatrix;
-  class EpetraPreconditioner;
+  class EpetraUserPreconditioner;
+  class TrilinosPreconditioner;
 
   /// This class implements Krylov methods for linear systems
   /// of the form Ax = b. It is a wrapper for the Krylov solvers
@@ -39,8 +45,8 @@ namespace dolfin
     EpetraKrylovSolver(std::string method = "default",
                        std::string pc_type = "default");
 
-    /// Create Krylov solver for a particular method and EpetraPreconditioner
-    EpetraKrylovSolver(std::string method, EpetraPreconditioner& prec);
+    /// Create Krylov solver for a particular method and TrilinosPreconditioner
+    EpetraKrylovSolver(std::string method, TrilinosPreconditioner& preconditioner);
 
     /// Destructor
     ~EpetraKrylovSolver();
@@ -57,19 +63,25 @@ namespace dolfin
     /// Return informal string representation (pretty-print)
     std::string str(bool verbose) const;
 
+    /// Return pointer to Aztec00
+    boost::shared_ptr<AztecOO> aztecoo() const;
+
   private:
 
     // Solver type
     std::string method;
 
-    // Preconditioner type
-    std::string pc_type;
-
     // Available solvers and preconditioners
     static const std::map<std::string, int> methods;
     static const std::map<std::string, int> pc_methods;
 
-    EpetraPreconditioner* prec;
+    // Underlying solver
+    boost::shared_ptr<AztecOO> solver;
+
+    // Preconditioner
+    boost::shared_ptr<TrilinosPreconditioner> preconditioner;
+
+    bool preconditioner_set;
 
   };
 
