@@ -2,7 +2,7 @@
 // Licensed under the GNU LGPL Version 2.1.
 //
 // Modified by Anders Logg, 2008.
-// Modified by Garth N. Wells, 2008, 2008.
+// Modified by Garth N. Wells, 2008, 2009.
 //
 // First added:  2008-04-21
 // Last changed: 2009-09-08
@@ -11,60 +11,58 @@
 
 #include <cstring>
 #include <iostream>
-#include <sstream>
 #include <iomanip>
-#include <dolfin/log/dolfin_log.h>
-#include "EpetraVector.h"
-#include "EpetraMatrix.h"
-#include "GenericSparsityPattern.h"
-#include "EpetraSparsityPattern.h"
-#include "EpetraFactory.h"
-#include <dolfin/common/Timer.h>
+#include <sstream>
+#include <utility>
 
 #include <Epetra_CrsGraph.h>
-#include <Epetra_FECrsGraph.h>
 #include <Epetra_CrsMatrix.h>
+#include <Epetra_FECrsGraph.h>
 #include <Epetra_FECrsMatrix.h>
 #include <Epetra_FEVector.h>
+#include <Epetra_MpiComm.h>
+#include <Epetra_SerialComm.h>
 #include <EpetraExt_MatrixMatrix.h>
 
+#include <ml_epetra_utils.h>
+
+#include <dolfin/main/MPI.h>
+#include <dolfin/log/dolfin_log.h>
+#include "EpetraVector.h"
+#include "GenericSparsityPattern.h"
+#include "SparsityPattern.h"
+#include "EpetraSparsityPattern.h"
+#include "EpetraFactory.h"
+#include "EpetraMatrix.h"
+
 using namespace dolfin;
 
 //-----------------------------------------------------------------------------
-EpetraMatrix::EpetraMatrix():
-    A(static_cast<Epetra_FECrsMatrix*>(0))
+EpetraMatrix::EpetraMatrix()
 {
-  // TODO: call Epetra_Init or something?
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
-EpetraMatrix::EpetraMatrix(uint M, uint N):
-    A(static_cast<Epetra_FECrsMatrix*>(0))
+EpetraMatrix::EpetraMatrix(uint M, uint N)
 {
-  // TODO: call Epetra_Init or something?
-  // Create Epetra matrix
   resize(M, N);
 }
 //-----------------------------------------------------------------------------
-EpetraMatrix::EpetraMatrix(const EpetraMatrix& A):
-  A(static_cast<Epetra_FECrsMatrix*>(0))
+EpetraMatrix::EpetraMatrix(const EpetraMatrix& A)
 {
   if (A.mat())
-  {
-    boost::shared_ptr<Epetra_FECrsMatrix> _A(new Epetra_FECrsMatrix(*A.mat()));
-    this->A = _A;
-  }
+    this->A.reset(new Epetra_FECrsMatrix(*A.mat()));
 }
 //-----------------------------------------------------------------------------
-EpetraMatrix::EpetraMatrix(boost::shared_ptr<Epetra_FECrsMatrix> A):
-    A(A)
+EpetraMatrix::EpetraMatrix(boost::shared_ptr<Epetra_FECrsMatrix> A) : A(A)
 {
-  // TODO: call Epetra_Init or something?
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
-EpetraMatrix::EpetraMatrix(const Epetra_CrsGraph& graph):
-    A(new Epetra_FECrsMatrix(Copy, graph))
+EpetraMatrix::EpetraMatrix(const Epetra_CrsGraph& graph)
+    : A(new Epetra_FECrsMatrix(Copy, graph))
 {
-  // TODO: call Epetra_Init or something?
+  // Do nothing
 }
 //-----------------------------------------------------------------------------
 EpetraMatrix::~EpetraMatrix()
@@ -74,24 +72,64 @@ EpetraMatrix::~EpetraMatrix()
 //-----------------------------------------------------------------------------
 void EpetraMatrix::resize(uint M, uint N)
 {
-  // Not yet implemented
   error("EpetraMatrix::resize(uint, unit) not yet implemented.");
 }
 //-----------------------------------------------------------------------------
 void EpetraMatrix::init(const GenericSparsityPattern& sparsity_pattern)
 {
-  if (!A.unique())
+  if (A && !A.unique())
     error("Cannot initialise EpetraMatrix. More than one object points to the underlying Epetra object.");
 
-  const EpetraSparsityPattern& epetra_pattern = dynamic_cast<const EpetraSparsityPattern&>(sparsity_pattern);
-  boost::shared_ptr<Epetra_FECrsMatrix> _A(new Epetra_FECrsMatrix(Copy, epetra_pattern.pattern()));
-  A = _A;
+  // Get local range
+  const std::pair<uint, uint> range = sparsity_pattern.local_range(0);
+  const uint num_local_rows = range.second - range.first;
+  const uint n0 = range.first;
+
+  const SparsityPattern& _pattern = dynamic_cast<const SparsityPattern&>(sparsity_pattern);
+  const std::vector<dolfin::Set<dolfin::uint> >& d_pattern = _pattern.diagonal_pattern();
+  const std::vector<dolfin::Set<dolfin::uint> >& o_pattern = _pattern.off_diagonal_pattern();
+
+  // Get number of non-zeroes per row (on and off diagonal)
+  std::vector<uint> dnum_nonzeros(num_local_rows);
+  std::vector<uint> onum_nonzeros(num_local_rows);
+  sparsity_pattern.num_nonzeros_diagonal(&dnum_nonzeros[0]);
+  sparsity_pattern.num_nonzeros_off_diagonal(&onum_nonzeros[0]);
+
+  // Create row map
+  EpetraFactory& f = EpetraFactory::instance();
+  Epetra_MpiComm comm = f.get_mpi_comm();
+  Epetra_Map row_map(sparsity_pattern.size(0), num_local_rows, 0, comm);
+
+  // Create Epetra_FECrsGraph
+  Epetra_FECrsGraph matrix_map(Copy, row_map, reinterpret_cast<int*>(&dnum_nonzeros[0]));
+
+  // Add diagonal block indices
+  std::vector<dolfin::Set<dolfin::uint> >::const_iterator row_set;
+  for (row_set = d_pattern.begin(); row_set != d_pattern.end(); ++row_set)
+  {
+    const uint global_row = row_set - d_pattern.begin() + n0;
+    const std::vector<dolfin::uint>& nz_entries = row_set->set();
+    std::vector<dolfin::uint>& _nz_entries = const_cast<std::vector<dolfin::uint>& >(nz_entries);
+    matrix_map.InsertGlobalIndices(global_row, row_set->size(), reinterpret_cast<int*>(&_nz_entries[0]));
+  }
+
+  // Add off-diagonal block indices
+  for (row_set = o_pattern.begin(); row_set != o_pattern.end(); ++row_set)
+  {
+    const uint global_row = row_set - o_pattern.begin() + n0;
+    const std::vector<dolfin::uint>& nz_entries = row_set->set();
+    std::vector<dolfin::uint>& _nz_entries = const_cast<std::vector<dolfin::uint>& >(nz_entries);
+    matrix_map.InsertGlobalIndices(global_row, row_set->size(), reinterpret_cast<int*>(&_nz_entries[0]));
+  }
+  matrix_map.GlobalAssemble();
+
+  // Create matrix
+  A.reset( new Epetra_FECrsMatrix(Copy, matrix_map) );
 }
 //-----------------------------------------------------------------------------
 EpetraMatrix* EpetraMatrix::copy() const
 {
-  EpetraMatrix* mcopy = new EpetraMatrix(*this);
-  return mcopy;
+  return new EpetraMatrix(*this);
 }
 //-----------------------------------------------------------------------------
 dolfin::uint EpetraMatrix::size(uint dim) const
@@ -102,38 +140,40 @@ dolfin::uint EpetraMatrix::size(uint dim) const
   return (dim == 0 ? M : N);
 }
 //-----------------------------------------------------------------------------
-void EpetraMatrix::get(double* block,
-		       uint m, const uint* rows,
-		       uint n, const uint* cols) const
+void EpetraMatrix::get(double* block, uint m, const uint* rows,
+		                   uint n, const uint* cols) const
 {
+  not_working_in_parallel("EpetraMatrix::get");
+
   assert(A);
 
-  int num_entities    = 0;
-  int * indices;
-  double * values;
+  int num_entities = 0;
+  int* indices;
+  double* values;
 
   // For each row in rows
   for(uint i = 0; i < m; ++i)
   {
     // Extract the values and indices from row: rows[i]
-    if (A->IndicesAreLocal()) {
+    if (A->IndicesAreLocal())
+    {
       int err = A->ExtractMyRowView(rows[i], num_entities, values, indices);
-      if (err!= 0) {
+      if (err != 0) {
         error("EpetraMatrix::get: Did not manage to perform Epetra_CrsMatrix::ExtractMyRowView.");
       }
     }
-    else {
+    else
+    {
       int err = A->ExtractGlobalRowView(rows[i], num_entities, values, indices);
-      if (err!= 0) {
+      if (err != 0)
         error("EpetraMatrix::get: Did not manage to perform Epetra_CRSMatrix::ExtractGlobalRowView.");
-      }
-
     }
 
-    int k = 0;
     // Step the indices to the start of cols
+    int k = 0;
     while (indices[k] < static_cast<int>(cols[0]))
       k++;
+
     // Fill the collumns in the block
     for (uint j = 0; j < n; j++)
     {
@@ -155,7 +195,7 @@ void EpetraMatrix::set(const double* block,
   assert(A);
   int err = A->ReplaceGlobalValues(m, reinterpret_cast<const int*>(rows),
                                    n, reinterpret_cast<const int*>(cols), block);
-  if (err!= 0)
+  if (err != 0)
     error("EpetraMatrix::set: Did not manage to perform Epetra_CrsMatrix::ReplaceGlobalValues.");
 }
 //-----------------------------------------------------------------------------
@@ -163,9 +203,7 @@ void EpetraMatrix::add(const double* block,
                        uint m, const uint* rows,
                        uint n, const uint* cols)
 {
-  Timer t0("Matrix add");
   assert(A);
-
   int err = A->SumIntoGlobalValues(m, reinterpret_cast<const int*>(rows),
                                    n, reinterpret_cast<const int*>(cols), block,
                                    Epetra_FECrsMatrix::ROW_MAJOR);
@@ -205,36 +243,36 @@ void EpetraMatrix::zero()
 {
   assert(A);
   int err = A->PutScalar(0.0);
-  if (err!= 0)
+  if (err != 0)
     error("EpetraMatrix::zero: Did not manage to perform Epetra_CrsMatrix::PutScalar.");
 }
 //-----------------------------------------------------------------------------
-void EpetraMatrix::apply()
+void EpetraMatrix::apply(std::string mode)
 {
   assert(A);
-  int err = A->GlobalAssemble();
-  if (err!= 0)
+  int err = 0;
+  if (mode == "add")
+    err = A->GlobalAssemble(Add);
+  else if (mode == "insert")
+    err = A->GlobalAssemble(Insert);
+  else
+    error("Unknown apply mode in EpetraMatrix::apply.");
+
+  if (err != 0)
     error("EpetraMatrix::apply: Did not manage to perform Epetra_CrsMatrix::GlobalAssemble.");
-  // TODO
-  //A->OptimizeStorage();
 }
 //-----------------------------------------------------------------------------
 std::string EpetraMatrix::str(bool verbose) const
 {
   assert(A);
-
   std::stringstream s;
-
   if (verbose)
   {
     warning("Verbose output for EpetraMatrix not implemented, calling Epetra Print directly.");
-
     A->Print(std::cout);
   }
   else
-  {
     s << "<EpetraMatrix of size " << size(0) << " x " << size(1) << ">";
-  }
 
   return s.str();
 }
@@ -242,53 +280,60 @@ std::string EpetraMatrix::str(bool verbose) const
 void EpetraMatrix::ident(uint m, const uint* rows)
 {
   assert(A);
-  double* values;
-  int* indices;
-  int* row_size = new int;
-  int r;
 
-  for (uint i=0; i<m; i++)
+  // FIXME: Is this the best way to do this?
+
+  // FIXME: This can be made more efficient by eliminating creation of some
+  //        obejcts inside the loop
+
+  const Epetra_CrsGraph& graph = A->Graph();
+  for (uint i = 0; i < m; ++i)
   {
-    r = rows[i];
-    int err = A->ExtractMyRowView(r, *row_size, values, indices);
-    if (err!= 0)
-      error("EpetraMatrix::ident: Did not manage to perform Epetra_CrsMatrix::ExtractMyRowView.");
-    memset(values, 0, (*row_size)*sizeof(double));
-    for (uint j=0; j<m; j++)
-    {
-      if (r == indices[j])
-      {
-        values[j] = 1.0;
-        break;
-      }
-    }
+    int row = rows[i];
+    int num_nz = graph.NumGlobalIndices(row);
+    std::vector<int> indices(num_nz);
+
+    int out_num = 0;
+    graph.ExtractGlobalRowCopy(row, num_nz, out_num, &indices[0]);
+
+    // Zero row
+    std::vector<double> block(num_nz);
+    int err = A->ReplaceGlobalValues(row, num_nz, &block[0], &indices[0]);
+    if (err != 0)
+      error("EpetraMatrix::ident: Did not manage to perform Epetra_CrsMatrix::ReplaceGlobalValues.");
+
+    // Place one on the diagonal
+    double one = 1.0;
+    A->ReplaceGlobalValues(row, 1, &one, &row);
   }
-  delete row_size;
 }
 //-----------------------------------------------------------------------------
 void EpetraMatrix::zero(uint m, const uint* rows)
 {
-  assert(A);
-  double* values;
-  int* indices;
-  int* row_size = new int;
-  int r;
+  // FIXME: This can be made more efficient by eliminating creation of some
+  //        obejcts inside the loop
 
-  for (uint i=0; i<m; i++)
+  assert(A);
+  const Epetra_CrsGraph& graph = A->Graph();
+  for (uint i = 0; i < m; ++i)
   {
-    r = rows[i];
-    int err = A->ExtractMyRowView(r, *row_size, values, indices);
-    if (err!= 0)
-      error("EpetraMatrix::zero: Did not manage to perform Epetra_CRSMatrix::ExtractMyRowView.");
-    memset(values, 0, (*row_size)*sizeof(double));
+    int row = rows[i];
+    int num_nz = graph.NumGlobalIndices(row);
+    std::vector<int> indices(num_nz);
+
+    int out_num = 0;
+    graph.ExtractGlobalRowCopy(row, num_nz, out_num, &indices[0]);
+
+    std::vector<double> block(num_nz);
+    int err = A->ReplaceGlobalValues(row, num_nz, &block[0], &indices[0]);
+    if (err != 0)
+      error("EpetraMatrix::zero: Did not manage to perform Epetra_CrsMatrix::ReplaceGlobalValues.");
   }
-  delete row_size;
 }
 //-----------------------------------------------------------------------------
 void EpetraMatrix::mult(const GenericVector& x_, GenericVector& Ax_) const
 {
   assert(A);
-
   const EpetraVector* x = dynamic_cast<const EpetraVector*>(x_.instance());
   if (!x)
     error("EpetraMatrix::mult: The vector x should be of type EpetraVector.");
@@ -299,18 +344,17 @@ void EpetraMatrix::mult(const GenericVector& x_, GenericVector& Ax_) const
 
   if (size(1) != x->size())
     error("EpetraMatrix::mult: Matrix and vector dimensions don't match for matrix-vector product.");
+
   Ax->resize(size(0));
 
   int err = A->Multiply(false, *(x->vec()), *(Ax->vec()));
-  if (err!= 0)
+  if (err != 0)
     error("EpetraMatrix::mult: Did not manage to perform Epetra_CRSMatrix::Multiply.");
-
 }
 //-----------------------------------------------------------------------------
 void EpetraMatrix::transpmult(const GenericVector& x_, GenericVector& Ax_) const
 {
   assert(A);
-
   const EpetraVector* x = dynamic_cast<const EpetraVector*>(x_.instance());
   if (!x)
     error("EpetraMatrix::transpmult: The vector x should be of type EpetraVector.");
@@ -321,40 +365,43 @@ void EpetraMatrix::transpmult(const GenericVector& x_, GenericVector& Ax_) const
 
   if (size(0) != x->size())
     error("EpetraMatrix::transpmult: Matrix and vector dimensions don't match for (transposed) matrix-vector product.");
+
   Ax->resize(size(1));
 
   int err = A->Multiply(true, *(x->vec()), *(Ax->vec()));
-  if (err!= 0)
+  if (err != 0)
     error("EpetraMatrix::transpmult: Did not manage to perform Epetra_CRSMatrix::Multiply.");
 }
 //-----------------------------------------------------------------------------
-void EpetraMatrix::getrow(uint row, std::vector<uint>& columns, std::vector<double>& values) const
+void EpetraMatrix::getrow(uint row, std::vector<uint>& columns,
+                          std::vector<double>& values) const
 {
+  not_working_in_parallel("EpetraMatrix::getrow");
+
   assert(A);
 
   // Temporary variables
-  int *indices;
+  int* indices;
   double* vals;
-  int* num_entries = new int;
+  int num_entries;
 
   // Extract data from Epetra matrix
-  int err = A->ExtractMyRowView(row, *num_entries, vals, indices);
-  if (err!= 0)
+  int err = A->ExtractMyRowView(row, num_entries, vals, indices);
+  if (err != 0)
     error("EpetraMatrix::getrow: Did not manage to perform Epetra_CrsMatrix::ExtractMyRowView.");
 
   // Put data in columns and values
-  columns.clear();
-  values.clear();
-  for (int i=0; i< *num_entries; i++)
+  columns.resize(num_entries);
+  values.resize(num_entries);
+  for (int i = 0; i < num_entries; i++)
   {
-    columns.push_back(indices[i]);
-    values.push_back(vals[i]);
+    columns[i] = indices[i];
+    values[i]  = vals[i];
   }
-
-  delete num_entries;
 }
 //-----------------------------------------------------------------------------
-void EpetraMatrix::setrow(uint row, const std::vector<uint>& columns, const std::vector<double>& values)
+void EpetraMatrix::setrow(uint row, const std::vector<uint>& columns,
+                          const std::vector<double>& values)
 {
   dolfin_not_implemented();
 }
@@ -364,9 +411,15 @@ LinearAlgebraFactory& EpetraMatrix::factory() const
   return EpetraFactory::instance();
 }
 //-----------------------------------------------------------------------------
+void EpetraMatrix::init(const EpetraSparsityPattern& sparsity_pattern)
+{
+  if (A && !A.unique())
+    error("Cannot initialise EpetraMatrix. More than one object points to the underlying Epetra object.");
+  A.reset(new Epetra_FECrsMatrix(Copy, sparsity_pattern.pattern()));
+}
+//-----------------------------------------------------------------------------
 boost::shared_ptr<Epetra_FECrsMatrix> EpetraMatrix::mat() const
 {
-  assert(A);
   return A;
 }
 //-----------------------------------------------------------------------------
@@ -374,7 +427,7 @@ const EpetraMatrix& EpetraMatrix::operator*= (double a)
 {
   assert(A);
   int err = A->Scale(a);
-  if (err!=0)
+  if (err !=0)
     error("EpetraMatrix::operator*=: Did not manage to perform Epetra_CrsMatrix::Scale.");
   return *this;
 }
@@ -383,7 +436,7 @@ const EpetraMatrix& EpetraMatrix::operator/= (double a)
 {
   assert(A);
   int err = A->Scale(1.0/a);
-  if (err!=0)
+  if (err !=0)
     error("EpetraMatrix::operator/=: Did not manage to perform Epetra_CrsMatrix::Scale.");
   return *this;
 }
@@ -401,5 +454,4 @@ const EpetraMatrix& EpetraMatrix::operator= (const EpetraMatrix& A)
   return *this;
 }
 //-----------------------------------------------------------------------------
-
 #endif
