@@ -12,6 +12,7 @@
 
 #ifdef HAS_TRILINOS
 
+#include <string>
 #include <vector>
 #include <boost/shared_ptr.hpp>
 #include <dolfin/common/Variable.h>
@@ -23,8 +24,11 @@ class Epetra_Map;
 namespace dolfin
 {
 
+  template <class T> class Array;
+  class GenericVector;
+
   /// This class provides a simple vector class based on Epetra.
-  /// It is a simple wrapper for an Epetra vector object (Epetre_FEVector)
+  /// It is a simple wrapper for an Epetra vector object (Epetra_FEVector)
   /// implementing the GenericVector interface.
   ///
   /// The interface is intentionally simple. For advanced usage,
@@ -36,13 +40,13 @@ namespace dolfin
   public:
 
     /// Create empty vector
-    EpetraVector();
+    EpetraVector(std::string type="global");
 
     /// Create vector of size N
-    explicit EpetraVector(uint N);
+    explicit EpetraVector(uint N, std::string type="global");
 
     /// Copy constructor
-    explicit EpetraVector(const EpetraVector& x);
+    EpetraVector(const EpetraVector& x);
 
     /// Create vector view from given Epetra_FEVector pointer
     explicit EpetraVector(boost::shared_ptr<Epetra_FEVector> vector);
@@ -62,7 +66,7 @@ namespace dolfin
     virtual void zero();
 
     /// Finalize assembly of tensor
-    virtual void apply();
+    virtual void apply(std::string mode);
 
     /// Return informal string representation (pretty-print)
     virtual std::string str(bool verbose) const;
@@ -87,18 +91,19 @@ namespace dolfin
     /// Add block of values
     virtual void add(const double* block, uint m, const uint* rows);
 
+    virtual void get_local(double* block, uint m, const uint* rows) const;
+
     /// Get all values on local process
-    virtual void get_local(double* values) const;
+    virtual void get_local(Array<double>& values) const;
 
     /// Set all values on local process
-    virtual void set_local(const double* values);
+    virtual void set_local(const Array<double>& values);
 
     /// Add all values to each entry on local process
-    virtual void add_local(const double* values);
+    virtual void add_local(const Array<double>& values);
 
     /// Gather entries into local vector x
-    virtual void gather(GenericVector& x, const std::vector<uint>& indices) const
-    { not_working_in_parallel("EpetraVector::gather)"); }
+    virtual void gather(GenericVector& x, const Array<uint>& indices) const;
 
     /// Add multiple of given vector (AXPY operation)
     virtual void axpy(double a, const GenericVector& x);
@@ -118,6 +123,9 @@ namespace dolfin
     /// Return sum of values of vector
     virtual double sum() const;
 
+    /// Return sum of selected rows in vector
+    virtual double sum(const Array<uint>& rows) const;
+
     /// Multiply vector by given number
     virtual const EpetraVector& operator*= (double a);
 
@@ -146,6 +154,9 @@ namespace dolfin
 
     //--- Special Epetra functions ---
 
+    /// Reset Epetra_FEVector
+    void reset(const Epetra_Map& map);
+
     /// Return Epetra_FEVector pointer
     boost::shared_ptr<Epetra_FEVector> vec() const;
 
@@ -157,6 +168,9 @@ namespace dolfin
     // Epetra_FEVector pointer
     boost::shared_ptr<Epetra_FEVector> x;
 
+    // Local/global vector
+    const std::string type;
+
   };
 
 }
