@@ -8,7 +8,7 @@
 // Modified by Martin Alnæs, 2008.
 //
 // First added:  2006-04-24
-// Last changed: 2009-09-08
+// Last changed: 2010-02-24
 
 #ifndef __GENERIC_MATRIX_H
 #define __GENERIC_MATRIX_H
@@ -70,7 +70,7 @@ namespace dolfin
     virtual void zero() = 0;
 
     /// Finalize assembly of tensor
-    virtual void apply() = 0;
+    virtual void apply(std::string mode) = 0;
 
     /// Return informal string representation (pretty-print)
     virtual std::string str(bool verbose) const = 0;
@@ -163,10 +163,14 @@ namespace dolfin
     virtual double getitem(std::pair<uint, uint> ij) const
     { double value(0); get(&value, 1, &ij.first, 1, &ij.second); return value; }
 
-    /// Set given entry to value
+    /// Set given entry to value. apply("insert") should be called before using
+    /// using the object.
     virtual void setitem(std::pair<uint, uint> ij, double value)
     { set(&value, 1, &ij.first, 1, &ij.second); }
 
+    /// Insert one on the diagonal for all zero rows
+    virtual void ident_zeros();
+
     typedef XMLMatrix XMLHandler;
 
   };
