@@ -63,7 +63,7 @@ namespace dolfin
     virtual void zero() = 0;
 
     /// Finalize assembly of tensor
-    virtual void apply() = 0;
+    virtual void apply(std::string mode) = 0;
 
     /// Return informal string representation (pretty-print)
     virtual std::string str(bool verbose) const = 0;
@@ -77,7 +77,8 @@ namespace dolfin
     template<class T> const T& down_cast() const
     {
       const T* t = dynamic_cast<const T*>(instance());
-      if (!t) error("GenericTensor cannot be cast to the requested type.");
+      if (!t)
+        error("GenericTensor cannot be cast to the requested type.");
       return *t;
     }
 
