@@ -5,24 +5,27 @@
 // Modified by Kent-Andre Mardal, 2008.
 // Modified by Ola Skavhaug, 2008.
 // Modified by Martin Sandve Alnes, 2009.
+// Modified by Johan Hake, 2009-2010.
 //
 // First added:  2006-04-25
-// Last changed: 2010-02-08
+// Last changed: 2010-03-07
 
 #ifndef __GENERIC_VECTOR_H
 #define __GENERIC_VECTOR_H
 
 #include <algorithm>
 #include <utility>
+#include <vector>
 #include <boost/lambda/lambda.hpp>
 #include "GenericSparsityPattern.h"
 #include "GenericTensor.h"
 
 namespace dolfin
 {
+  template<class T> class Array;
+  class XMLVector;
 
   /// This class defines a common interface for vectors.
-  class XMLVector;
 
   class GenericVector : public GenericTensor
   {
@@ -71,7 +74,7 @@ namespace dolfin
     virtual void zero() = 0;
 
     /// Finalize assembly of tensor
-    virtual void apply() = 0;
+    virtual void apply(std::string mode) = 0;
 
     /// Return informal string representation (pretty-print)
     virtual std::string str(bool verbose) const = 0;
@@ -101,16 +104,16 @@ namespace dolfin
     virtual void add(const double* block, uint m, const uint* rows) = 0;
 
     /// Get all values on local process
-    virtual void get_local(double* values) const = 0;
+    virtual void get_local(Array<double>& values) const = 0;
 
     /// Set all values on local process
-    virtual void set_local(const double* values) = 0;
+    virtual void set_local(const Array<double>& values) = 0;
 
     /// Add values to each entry on local process
-    virtual void add_local(const double* values) = 0;
+    virtual void add_local(const Array<double>& values) = 0;
 
     /// Gather entries into local vector x
-    virtual void gather(GenericVector& x, const std::vector<uint>& indices) const = 0;
+    virtual void gather(GenericVector& x, const Array<uint>& indices) const = 0;
 
     /// Add multiple of given vector (AXPY operation)
     virtual void axpy(double a, const GenericVector& x) = 0;
@@ -130,6 +133,10 @@ namespace dolfin
     /// Return sum of vector
     virtual double sum() const = 0;
 
+    /// Return sum of selected rows in vector. Repeated entries only summed once.
+    virtual double sum(const Array<uint>& rows) const
+    { error("GenericVector::sum(const Array<uint>& rows) not implemented by backend"); return 0.0; }
+
     /// Multiply vector by given number
     virtual const GenericVector& operator*= (double a) = 0;
 
@@ -157,9 +164,10 @@ namespace dolfin
       // FIXME: This could be more efficient by acting on the underling vector
       //        data
       std::vector<double> values(size());
-      get_local(&values[0]);
+      Array<double> _values(size(), &values[0]);
+      get_local(_values);
       std::for_each(values.begin(), values.end(), function);
-      set_local(&values[0]);
+      set_local(_values);
     }
 
     /// Apply lambda function
@@ -169,11 +177,13 @@ namespace dolfin
       //        data
       assert(x.size() == this->size());
       std::vector<double> values(size());
+      Array<double> _values(size(), values);
       std::vector<double> x_values(size());
-      this->get_local(&values[0]);
-      x.get_local(&x_values[0]);
+      Array<double> _x_values(size(), x_values);
+      this->get_local(_values);
+      x.get_local(_x_values);
       std::transform(x_values.begin(), x_values.end(), values.begin(), function);
-      this->set_local(&values[0]);
+      this->set_local(_values);
     }
 
     /// Return pointer to underlying data (const version)
@@ -200,7 +210,8 @@ namespace dolfin
     virtual double getitem(uint i) const
     { double value(0); get(&value, 1, &i); return value; }
 
-    /// Set given entry to value
+    /// Set given entry to value. apply("insert") should be called before using
+    /// using the object.
     virtual void setitem(uint i, double value)
     { set(&value, 1, &i); }
 
