@@ -34,8 +34,7 @@ namespace dolfin
     { DefaultFactory factory; matrix = factory.create_matrix(); matrix->resize(M, N); }
 
     /// Copy constructor
-    explicit Matrix(const Matrix& A) : matrix(A.matrix->copy())
-    {}
+    Matrix(const Matrix& A) : matrix(A.matrix->copy()) {}
 
     /// Destructor
     virtual ~Matrix()
@@ -60,8 +59,8 @@ namespace dolfin
     { matrix->zero(); }
 
     /// Finalize assembly of tensor
-    virtual void apply()
-    { matrix->apply(); }
+    virtual void apply(std::string mode)
+    { matrix->apply(mode); }
 
     /// Return informal string representation (pretty-print)
     virtual std::string str(bool verbose) const
