@@ -50,7 +50,7 @@ namespace dolfin
     PETScMatrix(uint M, uint N);
 
     /// Copy constructor
-    explicit PETScMatrix(const PETScMatrix& A);
+    PETScMatrix(const PETScMatrix& A);
 
     /// Create matrix from given PETSc Mat pointer
     explicit PETScMatrix(boost::shared_ptr<Mat> A);
@@ -73,7 +73,7 @@ namespace dolfin
     virtual void zero();
 
     /// Finalize assembly of tensor
-    virtual void apply();
+    virtual void apply(std::string mode);
 
     /// Return informal string representation (pretty-print)
     virtual std::string str(bool verbose) const;
