@@ -12,14 +12,14 @@
 #ifndef __VECTOR_H
 #define __VECTOR_H
 
-//#include <iostream>
-//#include <typeinfo>
 #include "DefaultFactory.h"
 #include "GenericVector.h"
 
 namespace dolfin
 {
 
+  template<class T> class Array;
+
   /// This class provides the default DOLFIN vector class,
   /// based on the default DOLFIN linear algebra backend.
 
@@ -36,11 +36,10 @@ namespace dolfin
     { DefaultFactory factory; vector = factory.create_vector(); vector->resize(N); }
 
     /// Copy constructor
-    explicit Vector(const Vector& x) : vector(x.vector->copy())
-    {}
+    Vector(const Vector& x) : vector(x.vector->copy()) {}
 
     /// Create a Vector from a GenericVetor
-    explicit Vector(const GenericVector& x) : vector(x.factory().create_vector())
+    Vector(const GenericVector& x) : vector(x.factory().create_vector())
     { vector = x.copy(); }
 
     /// Destructor
@@ -58,8 +57,8 @@ namespace dolfin
     { vector->zero(); }
 
     /// Finalize assembly of tensor
-    virtual void apply()
-    { vector->apply(); }
+    virtual void apply(std::string mode)
+    { vector->apply(mode); }
 
     /// Return informal string representation (pretty-print)
     virtual std::string str(bool verbose) const
@@ -96,19 +95,19 @@ namespace dolfin
     { vector->add(block, m, rows); }
 
     /// Get all values on local process
-    virtual void get_local(double* values) const
+    virtual void get_local(Array<double>& values) const
     { vector->get_local(values); }
 
     /// Set all values on local process
-    virtual void set_local(const double* values)
+    virtual void set_local(const Array<double>& values)
     { vector->set_local(values); }
 
     /// Add values to each entry on local process
-    virtual void add_local(const double* values)
+    virtual void add_local(const Array<double>& values)
     { vector->add_local(values); }
 
     /// Gather entries into local vector x
-    virtual void gather(GenericVector& x, const std::vector<uint>& indices) const
+    virtual void gather(GenericVector& x, const Array<uint>& indices) const
     { vector->gather(x, indices); }
 
     /// Add multiple of given vector (AXPY operation)
@@ -135,6 +134,9 @@ namespace dolfin
     virtual double sum() const
     { return vector->sum(); }
 
+    virtual double sum(const Array<uint>& rows) const
+    { return vector->sum(rows); }
+
     /// Multiply vector by given number
     virtual const Vector& operator*= (double a)
     { *vector *= a; return *this; }
