@@ -8,7 +8,7 @@
 // Modified by Dag Lindbo, 2008
 //
 // First added:  2006-07-05
-// Last changed: 2009-09-08
+// Last changed: 2010-06-28
 
 #ifndef __UBLAS_MATRIX_H
 #define __UBLAS_MATRIX_H
@@ -57,7 +57,7 @@ namespace dolfin
     uBLASMatrix(uint M, uint N);
 
     /// Copy constructor
-    explicit uBLASMatrix(const uBLASMatrix& A);
+    uBLASMatrix(const uBLASMatrix& A);
 
     /// Create matrix from given uBLAS matrix expression
     template <class E>
@@ -81,7 +81,7 @@ namespace dolfin
     virtual void zero();
 
     /// Finalize assembly of tensor
-    virtual void apply();
+    virtual void apply(std::string mode);
 
     /// Return informal string representation (pretty-print)
     virtual std::string str(bool verbose) const;
@@ -231,7 +231,7 @@ namespace dolfin
   template <class Mat>
   uint uBLASMatrix<Mat>::size(uint dim) const
   {
-    assert( dim < 2 );
+    assert(dim < 2);
     return (dim == 0 ? A.Mat::size1() : A.Mat::size2());
   }
   //---------------------------------------------------------------------------
@@ -516,7 +516,7 @@ namespace dolfin
     const SparsityPattern* pattern_pointer = dynamic_cast<const SparsityPattern*>(&sparsity_pattern);
     if (!pattern_pointer)
       error("Cannot convert GenericSparsityPattern to concrete SparsityPattern type. Aborting.");
-    const std::vector<Set<uint> >& pattern = pattern_pointer->pattern();
+    const std::vector<Set<uint> >& pattern = pattern_pointer->diagonal_pattern();
 
     // Add entries
     std::vector<Set<uint> >::const_iterator row;
@@ -534,14 +534,14 @@ namespace dolfin
   }
   //---------------------------------------------------------------------------
   template <>
-  inline void uBLASMatrix<ublas_sparse_matrix>::apply()
+  inline void uBLASMatrix<ublas_sparse_matrix>::apply(std::string mode)
   {
     // Make sure matrix assembly is complete
     A.complete_index1_data();
   }
   //---------------------------------------------------------------------------
   template <class Mat>
-  inline void uBLASMatrix<Mat>::apply()
+  inline void uBLASMatrix<Mat>::apply(std::string mode)
   {
     // Do nothing
   }
@@ -576,7 +576,7 @@ namespace dolfin
   void uBLASMatrix<Mat>::solveInPlace(B& X)
   {
     const uint M = A.size1();
-    assert( M == A.size2() );
+    assert(M == A.size2());
 
     // Create permutation matrix
     ublas::permutation_matrix<std::size_t> pmatrix(M);
