@@ -4,7 +4,7 @@
 // Modified by Ola Skavhaug, 2007, 2009.
 //
 // First added:  2003-03-13
-// Last changed: 2009-12-03
+// Last changed: 2010-06-07
 
 #ifndef __LOG_H
 #define __LOG_H
@@ -12,6 +12,7 @@
 #include <string>
 #include <cassert>
 #include <dolfin/common/types.h>
+#include "LogLevel.h"
 
 namespace dolfin
 {
@@ -64,10 +65,10 @@ namespace dolfin
   void logging(bool active=true);
 
   /// Set log level
-  void set_log_level(uint level);
+  void set_log_level(int level);
 
   /// Get log level
-  uint get_log_level();
+  int get_log_level();
 
   /// Print summary of timings and tasks, optionally clearing stored timings
   void summary(bool reset=false);
@@ -94,10 +95,9 @@ namespace dolfin
 
 // Not implemented error, reporting function name and line number
 #define dolfin_not_implemented() \
-  do \
-  { \
-    dolfin::__debug(__FILE__, __LINE__, __FUNCTION__, "Sorry, this function has not been implemented."); \
-    error("Not implemented."); \
+  do { \
+    error("The function '%s' has not been implemented (in %s line %d).", \
+          __FUNCTION__, __FILE__, __LINE__); \
   } while (false)
 
 #endif
