@@ -8,7 +8,7 @@
 // Modified by Andre Massing, 2009-2010.
 //
 // First added:  2006-05-09
-// Last changed: 2010-02-05
+// Last changed: 2010-04-29
 
 #include <sstream>
 
@@ -19,10 +19,6 @@
 #include <dolfin/io/File.h>
 #include <dolfin/common/Timer.h>
 #include <dolfin/common/utils.h>
-#include <dolfin/adaptivity/AdaptiveObjects.h>
-#include "UniformMeshRefinement.h"
-#include "LocalMeshRefinement.h"
-#include "LocalMeshCoarsening.h"
 #include "IntersectionOperator.h"
 #include "TopologyComputation.h"
 #include "MeshSmoothing.h"
@@ -109,6 +105,10 @@ dolfin::uint Mesh::init(uint dim) const
   if (_topology.size(dim) > 0)
     return _topology.size(dim);
 
+  // Skip vertices and cells (should always exist)
+  if (dim == 0 || dim == _topology.dim())
+    return _topology.size(dim);
+
   // Check that mesh is ordered
   if (!ordered())
     error("Mesh is not ordered according to the UFC numbering convention, consider calling mesh.order().");
@@ -190,21 +190,12 @@ bool Mesh::ordered() const
   return _ordered;
 }
 //-----------------------------------------------------------------------------
-void Mesh::refine()
-{
-  AdaptiveObjects::refine(this, 0);
-}
-//-----------------------------------------------------------------------------
-void Mesh::refine(MeshFunction<bool>& cell_markers)
-{
-  AdaptiveObjects::refine(this, &cell_markers);
-}
-//-----------------------------------------------------------------------------
+/*
 void Mesh::coarsen()
 {
   // FIXME: Move implementation to separate class and just call function here
 
-  info("No cells marked for coarsening, assuming uniform mesh coarsening.");
+  info(DBG, "No cells marked for coarsening, assuming uniform mesh coarsening.");
   MeshFunction<bool> cell_marker(*this);
   cell_marker.init(this->topology().dim());
   for (CellIterator c(*this); !c.end(); ++c)
@@ -225,6 +216,7 @@ void Mesh::coarsen(MeshFunction<bool>& cell_markers, bool coarsen_boundary)
   // Mesh may not be ordered
   _ordered = false;
 }
+*/
 //-----------------------------------------------------------------------------
 void Mesh::move(BoundaryMesh& boundary, ALEType method)
 {
@@ -241,10 +233,19 @@ void Mesh::move(const Function& displacement)
   ALE::move(*this, displacement);
 }
 //-----------------------------------------------------------------------------
-void Mesh::smooth(uint num_smoothings)
+void Mesh::smooth(uint num_iterations)
 {
-  for (uint i = 0; i < num_smoothings; i++)
-    MeshSmoothing::smooth(*this);
+  MeshSmoothing::smooth(*this, num_iterations);
+}
+//-----------------------------------------------------------------------------
+void Mesh::smooth_boundary(uint num_iterations, bool harmonic_smoothing)
+{
+  MeshSmoothing::smooth_boundary(*this, num_iterations, harmonic_smoothing);
+}
+//-----------------------------------------------------------------------------
+void Mesh::snap_boundary(const SubDomain& sub_domain, bool harmonic_smoothing)
+{
+  MeshSmoothing::snap_boundary(*this, sub_domain, harmonic_smoothing);
 }
 //-----------------------------------------------------------------------------
 void Mesh::all_intersected_entities(const Point & point, uint_set & ids_result) const
@@ -255,7 +256,7 @@ void Mesh::all_intersected_entities(const Point & point, uint_set & ids_result)
 void Mesh::all_intersected_entities(const std::vector<Point> & points, uint_set & ids_result) const
 {
   _intersection_operator.all_intersected_entities(points, ids_result);
-} 
+}
 //-----------------------------------------------------------------------------
 void Mesh::all_intersected_entities(const MeshEntity & entity, std::vector<uint> & ids_result) const
 {
@@ -277,6 +278,20 @@ int Mesh::any_intersected_entity(const Point & point) const
   return _intersection_operator.any_intersected_entity(point);
 }
 //-----------------------------------------------------------------------------
+Point Mesh::closest_point(const Point & point) const
+{
+  return _intersection_operator.closest_point(point);
+}
+dolfin::uint Mesh::closest_cell(const Point & point) const
+{
+  return _intersection_operator.closest_cell(point);
+}
+//-----------------------------------------------------------------------------
+std::pair<Point,dolfin::uint> Mesh::closest_point_and_cell(const Point & point) const
+{
+  return _intersection_operator.closest_point_and_cell(point);
+}
+//-----------------------------------------------------------------------------
 IntersectionOperator& Mesh::intersection_operator()
 {
   return _intersection_operator;
