@@ -4,7 +4,7 @@
 // Modified by Garth N. Wells, 2008.
 //
 // First added:  2006-05-08
-// Last changed: 2009-09-08
+// Last changed: 2010-04-29
 
 #ifndef __MESH_GEOMETRY_H
 #define __MESH_GEOMETRY_H
@@ -129,6 +129,9 @@ namespace dolfin
 
   private:
 
+    // Friends
+    friend class BinaryFile;
+
     // Euclidean dimension
     uint _dim;
 
