@@ -2,7 +2,7 @@
 // Licensed under the GNU LGPL Version 2.1.
 //
 // First added:  2007-04-10
-// Last changed: 2009-10-22
+// Last changed: 2010-03-02
 
 #ifndef __SUB_DOMAIN_H
 #define __SUB_DOMAIN_H
@@ -13,6 +13,8 @@
 namespace dolfin
 {
 
+  template<class T> class Array;
+
   /// This class defines the interface for definition of sub domains.
   /// Alternatively, sub domains may be defined by a Mesh and a
   /// MeshFunction<uint> over the mesh.
@@ -28,11 +30,14 @@ namespace dolfin
     virtual ~SubDomain();
 
     /// Return true for points inside the subdomain
-    virtual bool inside(const double* x, bool on_boundary) const;
+    virtual bool inside(const Array<double>& x, bool on_boundary) const;
 
     /// Map coordinate x in domain H to coordinate y in domain G (used for
     /// periodic boundary conditions)
-    virtual void map(const double* x, double* y) const;
+    virtual void map(const Array<double>& x, Array<double>&) const;
+
+    /// Snap coordinate to boundary of sub domain
+    virtual void snap(Array<double>& x) const {}
 
     /// Set sub domain markers for given subdomain
     void mark(MeshFunction<uint>& sub_domains, uint sub_domain) const;
