@@ -7,7 +7,7 @@
 // Modified by Kristoffer Selim, 2008.
 //
 // First added:  2006-06-05
-// Last changed: 2010-01-19
+// Last changed: 2010-06-15
 
 #include <algorithm>
 #include <dolfin/log/dolfin_log.h>
@@ -272,6 +272,9 @@ double TetrahedronCell::normal(const Cell& cell, uint facet, uint i) const
 //-----------------------------------------------------------------------------
 Point TetrahedronCell::normal(const Cell& cell, uint facet) const
 {
+  // Make sure we have facets
+  cell.mesh().init(3, 2);
+
   // Create facet from the mesh and local facet number
   Facet f(cell.mesh(), cell.entities(2)[facet]);
 
@@ -325,10 +328,10 @@ double TetrahedronCell::facet_area(const Cell& cell, uint facet) const
   Facet f(cell.mesh(), cell.entities(2)[facet]);
 
   // Get mesh geometry
-  const MeshGeometry& geometry = cell.mesh().geometry();
+  const MeshGeometry& geometry = f.mesh().geometry();
 
   // Get the coordinates of the three vertices
-  const uint* vertices = cell.entities(0);
+  const uint* vertices = f.entities(0);
   const double* x0 = geometry.x(vertices[0]);
   const double* x1 = geometry.x(vertices[1]);
   const double* x2 = geometry.x(vertices[2]);
