@@ -3,11 +3,13 @@
 //
 // Modified by Anders Logg, 2005-2009.
 // Modified by Martin Alnes, 2008.
+// Modified by Johan Hake, 2010.
 //
 // First added:  2005-10-23
-// Last changed: 2010-02-15
+// Last changed: 2010-04-22
 
 #include <iostream>
+#include <dolfin/common/constants.h>
 #include <dolfin/common/NoDeleter.h>
 #include <dolfin/la/GenericLinearSolver.h>
 #include <dolfin/la/LinearSolver.h>
@@ -24,12 +26,14 @@ Parameters NewtonSolver::default_parameters()
 {
   Parameters p("newton_solver");
 
-  p.add("maximum_iterations",    50);
-  p.add("relative_tolerance",    1e-9);
-  p.add("absolute_tolerance",    1e-10);
-  p.add("convergence_criterion", "residual");
-  p.add("method",                "full");
-  p.add("report",                true);
+  p.add("maximum_iterations",      50);
+  p.add("relative_tolerance",      1e-9);
+  p.add("absolute_tolerance",      1e-10);
+  p.add("convergence_criterion",   "residual");
+  p.add("method",                  "full");
+  p.add("relaxation_parameter",    1.0);
+  p.add("report",                  true);
+  p.add("error_on_nonconvergence", true);
 
   return p;
 }
@@ -40,6 +44,7 @@ NewtonSolver::NewtonSolver(std::string solver_type, std::string pc_type)
 {
   // Set default parameters
   parameters = default_parameters();
+  parameters.add(solver->parameters);
 }
 //-----------------------------------------------------------------------------
 NewtonSolver::NewtonSolver(GenericLinearSolver& solver, LinearAlgebraFactory& factory)
@@ -90,7 +95,11 @@ std::pair<dolfin::uint, bool> NewtonSolver::solve(NonlinearProblem& nonlinear_pr
       newton_converged = converged(*b, *dx, nonlinear_problem);
 
     // Update solution
-    x -= (*dx);
+    const double relaxation = parameters["relaxation_parameter"];
+    if (std::abs(1.0 - relaxation) < DOLFIN_EPS)
+      x -= (*dx);
+    else
+      x.axpy(-relaxation, *dx);
 
     // Update number of iterations
     ++newton_iteration;
@@ -105,10 +114,16 @@ std::pair<dolfin::uint, bool> NewtonSolver::solve(NonlinearProblem& nonlinear_pr
   }
 
   if (newton_converged)
-    info("Newton solver finished in %d iterations and %d linear solver iterations.",
+    info(PROGRESS, "Newton solver finished in %d iterations and %d linear solver iterations.",
             newton_iteration, krylov_iterations);
   else
-    warning("Newton solver did not converge.");
+  {
+    bool error_on_nonconvergence = parameters["error_on_nonconvergence"];
+    if (error_on_nonconvergence)
+      error("Newton solver did not converge.");
+    else
+      warning("Newton solver did not converge.");
+  }
 
   end();
 
