@@ -4,7 +4,7 @@
 // Modified by Garth N. Wells
 //
 // First added:  2005-01-27
-// Last changed: 2009-09-08
+// Last changed: 2010-06-07
 
 #include <string>
 #include <algorithm>
@@ -43,7 +43,7 @@ MultiAdaptiveTimeSlab::MultiAdaptiveTimeSlab(ODE& ode) :
   real_zero(N, u);
 
   // Initialize transpose of dependencies if necessary
-  info("Computing transpose (inverse) of dependency pattern.");
+  info(TRACE, "Computing transpose (inverse) of dependency pattern.");
   if (ode.dependencies.sparse() && !ode.transpose.sparse())
     ode.transpose.transp(ode.dependencies);
 }
@@ -100,7 +100,7 @@ real MultiAdaptiveTimeSlab::build(real a, real b)
 //-----------------------------------------------------------------------------
 bool MultiAdaptiveTimeSlab::solve()
 {
-  //info("Solving time slab system on [%f, %f].", _a, _b);
+  //info(TRACE, "Solving time slab system on [%f, %f].", _a, _b);
 
   // Copy u0 to u. This happens automatically in feval if user has set
   // dependencies correctly, but you never know...
@@ -120,7 +120,7 @@ bool MultiAdaptiveTimeSlab::solve()
   //for (uint i = 0; i < N; i++)
   // {
   //  real endval = jx[elast[i] * method->nsize() + method->nsize() - 1];
-  //  info("i = %d: u = %.16e", i, endval);
+  //  info(DBG, "i = %d: u = %.16e", i, endval);
   // }
 }
 //-----------------------------------------------------------------------------
@@ -294,7 +294,7 @@ real MultiAdaptiveTimeSlab::rsample(uint i, real t)
 //-----------------------------------------------------------------------------
 void MultiAdaptiveTimeSlab::save_solution(ODESolution& u)
 {
-  //Not implemented
+  // FIXME: Not implemented
 }
 //-----------------------------------------------------------------------------
 std::string MultiAdaptiveTimeSlab::str(bool verbose) const
@@ -418,7 +418,7 @@ void MultiAdaptiveTimeSlab::create_e(uint index, uint subslab, real a, real b)
   // Get next available position
   uint pos = size_e.next++;
 
-  //info("  Creating element e = %d for i = %d at [%f, %f]", pos, index, a, b);
+  //info(DBG, "  Creating element e = %d for i = %d at [%f, %f]", pos, index, a, b);
 
   //if ( index == 145 )
   //  cout << "Modified: " << b - a << endl << endl;
@@ -456,7 +456,7 @@ void MultiAdaptiveTimeSlab::create_d(uint i0, uint e0, uint s0, real a0, real b0
   // Add dependencies to elements that depend on the given element if the
   // depending elements use larger time steps
 
-  //info("Checking dependencies to element %d (component %d)", element, index);
+  //info(TRACE, "Checking dependencies to element %d (component %d)", element, index);
 
   // Get list of components depending on current component
   const std::vector<uint>& deps = ode.transpose[i0];
@@ -486,7 +486,7 @@ void MultiAdaptiveTimeSlab::create_d(uint i0, uint e0, uint s0, real a0, real b0
     if ( !within(a0, b0, a1, b1) || s0 == s1 )
       continue;
 
-    //info("  Checking element %d (component %d)", e1, i1);
+    //info(DBG, "  Checking element %d (component %d)", e1, i1);
 
     // Iterate over dofs for element
     for (uint n = 0; n < method->nsize(); n++)
@@ -494,7 +494,7 @@ void MultiAdaptiveTimeSlab::create_d(uint i0, uint e0, uint s0, real a0, real b0
       //const uint j = j1 + n;
       const real t = a1 + k1*method->npoint(n);
 
-      //info("    Checking dof at t = %f", t);
+      //info(DBG, "    Checking dof at t = %f", t);
 
       // Check if dof is contained in the current element
       if ( within(t, a0, b0) )
@@ -528,7 +528,7 @@ void MultiAdaptiveTimeSlab::alloc_s(uint newsize)
 
   if ( newsize <= size_s.size ) return;
 
-  //info("Reallocating: ns = %d", newsize);
+  //info(DBG, "Reallocating: ns = %d", newsize);
 
   Alloc::realloc(&sa, size_s.size, newsize);
   Alloc::realloc(&sb, size_s.size, newsize);
@@ -542,7 +542,7 @@ void MultiAdaptiveTimeSlab::alloc_e(uint newsize)
 
   if ( newsize <= size_e.size ) return;
 
-  //info("Reallocating: ne = %d", newsize);
+  //info(DGG, "Reallocating: ne = %d", newsize);
 
   Alloc::realloc(&ei, size_e.size, newsize);
   Alloc::realloc(&es, size_e.size, newsize);
@@ -558,7 +558,7 @@ void MultiAdaptiveTimeSlab::alloc_j(uint newsize)
 
   if ( newsize <= size_j.size ) return;
 
-  //info("Reallocating: nj = %d", newsize);
+  //info(DBG, "Reallocating: nj = %d", newsize);
 
   Alloc::realloc(&jx, size_j.size, newsize);
 
@@ -571,7 +571,7 @@ void MultiAdaptiveTimeSlab::alloc_d(uint newsize)
 
   if ( newsize <= size_d.size ) return;
 
-  //info("Reallocating: nd = %d", newsize);
+  //info(DBG, "Reallocating: nd = %d", newsize);
 
   Alloc::realloc(&de, size_d.size, newsize);
 
