@@ -32,7 +32,7 @@ public:
   }
 
   /// Return true for points inside the sub domain
-  bool inside(const double* x, bool on_boundary) const
+  bool inside(const Array<double>& x, bool on_boundary) const
   {
     %(inside)s
   }
@@ -43,7 +43,7 @@ public:
 # TODO: Support implementation of map as well
 """
   /// Map coordinate x in domain H to coordinate y in domain G (used for periodic boundary conditions)
-  void map(const double* x, double* y) const
+  void map(const Array<double>& x, Array<double>& y) const
   {
     %(map)s
   }
@@ -51,19 +51,19 @@ public:
 
 def expression_to_subdomain(expr, classname):
     "Generates code for a dolfin::SubDomain subclass for a single expression."
-    
+
     # Assure we have a simple string expression
     assert isinstance(expr, str)
-    
+
     # Extract code fragments from the expr and defaults
     fragments = expression_to_code_fragments([expr], {}, ["x", "on_boundary","DOLFIN_EPS"])
-    
+
     # Generate code for inside()
     insidecode = "  return %s;" % expr
-    
+
     # Generate code for map()
     #mapcode = "..."
-    
+
     # Connect the code fragments using the function template code
     fragments["classname"] = classname
     fragments["inside"]    = insidecode
@@ -75,7 +75,7 @@ def compile_subdomain_code(code, classnames = None):
     # Autodetect classnames:
 
     _classnames = re.findall(r"class[ ]+([\w]+).*", code)
-    
+
     # Just a little assertion for safety:
     if classnames is None:
         classnames = _classnames
@@ -91,32 +91,32 @@ namespace dolfin
 """
 }
 """
-    
+
     # Compile the extension module
     compiled_module = compile_extension_module(\
                                 code,
                                 dolfin_module_import=["common","mesh","function"],
 #                                additional_declarations=_numpy_typemaps,
                                 use_numpy_typemaps=False)
-    
+
     # Construct instances of the compiled subdomain classes
     subdomains = [getattr(compiled_module, name)() for name in classnames]
     return subdomains
 
 def compile_subdomains(expressions):
     """Compiles C++ string expressions into dolfin::SubDomain instances.
-    
+
     The variable 'expressions' can either be a str or a list.
-    
+
     If 'expressions' is a str, it is interpreted as a C++ string
     with complete implementations of subclasses of dolfin::SubDomain.
-    The compiled subdomains returned will be in the same order 
+    The compiled subdomains returned will be in the same order
     as they are defined in this code.
 
     If it is a list, each item of the list is interpreted as
-    a logical 'inside' expression, and the compiled subdomains 
+    a logical 'inside' expression, and the compiled subdomains
     returned will be in the same order as they occur in this list.
-    
+
     If an expression string contains a name, it is assumed to
     be a scalar variable name, and is added as a public member
     of the generated subdomain. The exceptions are set in the
