@@ -351,7 +351,7 @@ class Expression(object):
 
     >>> f0 = Expression('sin(x[0]) + cos(x[1])')
     >>> f1 = Expression(('cos(x[0])', 'sin(x[1])'), element = V.ufl_element())
-    Here, f0 is is scalar and f1 is vector-valued. 
+    Here, f0 is is scalar and f1 is vector-valued.
 
     Tensor expressions of rank 2 (matrices) may also be created:
 
@@ -450,7 +450,7 @@ class Expression(object):
                     value[0] = -1.0
 
     >>> f1 = MyExpression1()
-    
+
     The user can customize initialization of derived Expressions, however because of
     magic behind the sceens a user need pass optional arguments to __init__ using
     **kwargs, and _not_ calling the base class __init__:
@@ -463,7 +463,7 @@ class Expression(object):
             ...
 
     >>> f2 = MyExpression1(mesh=mesh, domain=domain)
-    
+
     Note that subclassing may be significantly slower than using JIT-compiled
     expressions. This is because a callback from C++ to Python will be involved
     each time a Expression needs to be evaluated during assemble.
@@ -666,7 +666,7 @@ def _auto_select_element_from_shape(shape, cell=None, degree=None):
     else:
         element = ufl.TensorElement(Family, cell, degree, shape=shape)
 
-    cpp.info("Automatic selection of expression element: " + str(element))
+    cpp.debug("Automatic selection of expression element: " + str(element))
 
     return element
 
